package com.baojia.mebike.base

import android.os.Bundle
import android.text.TextUtils
import android.view.View
import androidx.core.content.ContextCompat
import androidx.recyclerview.widget.RecyclerView
import com.baojia.mebike.R
import com.baojia.mebike.feature.model.IRefreshDataView
import com.baojia.mebike.util.DensityUtil
import com.baojia.mebike.util.Toast
import com.baojia.mebike.util.recyclerview.RecycleViewDivider
import com.scwang.smartrefresh.header.MaterialHeader
import com.scwang.smartrefresh.layout.api.RefreshLayout
import com.scwang.smartrefresh.layout.listener.OnLoadmoreListener
import com.scwang.smartrefresh.layout.listener.OnRefreshListener
import kotlinx.android.synthetic.main.layout_nodata.*
import kotlinx.android.synthetic.main.layout_page_error.*
import kotlinx.android.synthetic.main.layout_page_no_net.*
import kotlinx.android.synthetic.main.layout_recyclerview_only.*

/**
 * +----------------------------------------------------------------------
 * | @time 2018/12/19:2:10 PM
 * | @author house
 * | @class_describe 刷新列表父类
 * +----------------------------------------------------------------------
 **/
abstract class BaseRefreshActivity<P : IBasePresenter, V : IRefreshDataView<P>> : BaseActivity(), OnRefreshListener,
        OnLoadmoreListener, IRefreshDataView<P> {


    override fun layoutId(): Int {
        return R.layout.layout_recyclerview_only
    }

    override fun setTitle() = setCenterTitle()

    override fun bindView(savedInstanceState: Bundle?) {

        //刷新效果添加    也可以全局设置在application里边
        refreshLayout.refreshHeader = MaterialHeader(this).setShowBezierWave(false)
                .setColorSchemeColors(ContextCompat.getColor(this, R.color.main_color)) //设置刷新为官方推介
        refreshLayout.setEnableHeaderTranslationContent(false)//刷新时和官方一致   内容不随刷新动
        refreshLayout.setPrimaryColorsId(R.color.main_color, R.color.main_color, R.color.main_color) //圈圈颜色


        refreshLayout.setOnRefreshListener(this)
        refreshLayout.setOnLoadmoreListener(this)

        setViewClickDuration(btPageErrorRefresh, 1)
        setViewClickDuration(btTrayAgain, 1)

        recyclerview.setHasFixedSize(true)

        initAdapter()
    }

    override fun onResume() {
        super.onResume()
        refreshLayout.autoRefresh()
    }

    protected abstract fun setCenterTitle(): String

    override fun onLoadmore(refreshlayout: RefreshLayout?) {
        refreshlayout?.finishRefresh(5000)//五秒后接口还没通强制关闭刷新效果
        onLoadMore()
    }

    override fun onRefresh(refreshlayout: RefreshLayout?) {
        refreshlayout?.finishRefresh(5000)//五秒后接口还没通强制关闭刷新效果
        onRefresh()
    }

    override fun setViewClick(view: View?) {
        super.setViewClick(view)
        when (view?.id) {
            R.id.btPageErrorRefresh//加载错误
                , R.id.btTrayAgain//网络错误
            -> refreshLayout.autoRefresh()

        }
    }

    /**
     * 初始化adapter
     */
    protected abstract fun initAdapter()

    /**
     * 刷新数据
     */
    protected abstract fun onRefresh()

    protected abstract fun getAdapter(): BaseCommonAdapter<Any?>

    /**
     * 加载更多数据
     */
    protected abstract fun onLoadMore()


    override fun refreshDataSucceed() {
        //结束刷新
        refreshLayout.finishRefresh()
        refreshLayout.isLoadmoreFinished = false
    }

    override fun refreshDataFailed(result: String?) {
        refreshLayout.finishRefresh().isLoadmoreFinished = true
        if (!TextUtils.isEmpty(result)) {
            Toast.show(this, result)
        }
    }

    override fun loadMoreDataSucceed() {
        refreshLayout.finishLoadmore(true)
    }

    override fun loadMoreDataFailed(result: String?) {
        refreshLayout.finishLoadmore().isLoadmoreFinished = false
        if (!TextUtils.isEmpty(result)) {
            Toast.show(this, result)
        }
    }

    override fun showNoDataPage() {
        getAdapter()?.let {
            if (it.itemCount as Int <= 0) {
                llNodata.visibility = View.VISIBLE
            }
        }
        refreshLayout.isLoadmoreFinished = true
    }

    override fun showNoNetPage() {
        getAdapter()?.let {
            if (it.itemCount as Int <= 0) {
                llNonet.visibility = View.VISIBLE
            }
        }
        refreshLayout.isLoadmoreFinished = true
    }

    override fun showErrorPage() {

        getAdapter()?.let {
            if (it.itemCount as Int <= 0) {
                llError.visibility = View.VISIBLE
            }
        }


        refreshLayout.isLoadmoreFinished = true
    }

    override fun hideAllPage() {
        llNonet.visibility = View.GONE
        llError.visibility = View.GONE
        llNodata.visibility = View.GONE
    }

    override fun setPresenter(presenter: P) {
        this.setIPresenter(presenter)
    }

}