package com.baojia.mebike.dialog

import android.content.Context
import android.os.Bundle
import android.view.View
import androidx.fragment.app.FragmentManager
import com.amap.api.maps.model.LatLng
import com.baojia.mebike.R
import com.baojia.mebike.base.BaseCompatDialogFragment
import com.baojia.mebike.data.CommData
import com.baojia.mebike.map.AMapUtil
import com.baojia.mebike.util.APKUtil.isAvilible
import com.baojia.mebike.util.DensityUtil
import com.baojia.mebike.util.JumpActivity
import com.baojia.mebike.util.Toast
import kotlinx.android.synthetic.main.dialog_map_select.*


/**
 * +----------------------------------------------------------------------
 * | @time 2018/12/24:6:04 PM
 * | @author house
 * | @class_describe 地图选择弹窗
 * +----------------------------------------------------------------------
 **/
class SelectMapDialog : BaseCompatDialogFragment(), View.OnClickListener {

    private var gdLongitude: Double = 0.0
    private var gdLatitude: Double = 0.0
    private var bdLatitude: Double = 0.0
    private var bdLongitude: Double = 0.0

    override fun setContentView(): Int {
        return R.layout.dialog_map_select
    }

    override fun bindView() {

        setDialogBottom()

        gdLatitude = bundle.getDouble("gdLatitude")
        gdLongitude = bundle.getDouble("gdLongitude")
        bdLatitude = bundle.getDouble("bdLatitude")
        bdLongitude = bundle.getDouble("bdLongitude")

        if (bdLatitude == 0.0 && bdLongitude == 0.0) {
            baiduMapButton.visibility = View.GONE
            lineImageView.visibility = View.GONE
        }

        if (gdLatitude == 0.0 && gdLongitude == 0.0) {
            gaodeMapButton.visibility = View.GONE
            lineImageView.visibility = View.GONE
        }

        baiduMapButton.setOnClickListener(this)
        gaodeMapButton.setOnClickListener(this)
        cancelButton.setOnClickListener(this)


    }


    override fun getStyle(): Int {
        return R.style.BottomAnimateDialog
    }

    override fun getWidth(): Int {
        return CommData.getScreen()[0] - DensityUtil.dip2px(activity, 20f)
    }

    override fun onClick(v: View?) {
        when (v) {
            baiduMapButton -> {
                dismiss()
                JumpActivity.OpenBaidu(activity, bdLatitude, bdLongitude)
            }
            gaodeMapButton -> {
                dismiss()
                JumpActivity.OpenAMapNavi(activity, LatLng(gdLatitude, gdLongitude))
            }
            cancelButton -> {
                dismiss()
            }
        }
    }

    companion object {
        @JvmStatic
        fun show(mContext: Context, fragmentManager: FragmentManager, gdLatitude: Double = 0.0, gdLongitude: Double = 0.0) {

            var bundle: Bundle? = null

            if (isAvilible(mContext, "com.baidu.BaiduMap")) {//传入指定应用包名
                // 百度地图存在
                if (bundle == null) {
                    bundle = Bundle()
                }

                val baidu = AMapUtil.gaoDeToBaidu(gdLatitude, gdLongitude);

                baidu?.let {
                    if (it.size > 1) {
                        bundle?.putDouble("bdLongitude", it[1])
                        bundle?.putDouble("bdLatitude", it[0])
                    }
                }
            }

            if (isAvilible(mContext, "com.autonavi.minimap")) {
                // 高德地图存在
                if (bundle == null) {
                    bundle = Bundle()
                }
                bundle?.putDouble("gdLatitude", gdLatitude)
                bundle?.putDouble("gdLongitude", gdLongitude)
            }

            if (bundle != null) {
                val selectMapDialog = SelectMapDialog()
                selectMapDialog.arguments = bundle
                selectMapDialog.show(fragmentManager, "SelectMapDialog")
            } else {
                Toast.show(mContext, "未安装高德地图/百度地图")
            }
        }


    }

}