package com.baojia.mebike.feature.exclusive.detail

import android.content.DialogInterface
import android.os.Bundle
import android.text.TextUtils
import android.view.View
import androidx.fragment.app.FragmentManager
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.baojia.mebike.R
import com.baojia.mebike.base.BaseCompatDialogFragment
import com.baojia.mebike.data.CommData
import com.baojia.mebike.data.response.exclusive.IWillExchangeResponse
import com.baojia.mebike.util.DensityUtil
import com.baojia.mebike.util.ToolBox
import com.baojia.mebike.util.recyclerview.RecycleViewDivider
import kotlinx.android.synthetic.main.dialog_exchange.*
import kotlinx.android.synthetic.main.include_bottom_common.*
import kotlinx.android.synthetic.main.include_payment.*
import kotlinx.android.synthetic.main.layout_tips_common.*

class ExchangeDialog : BaseCompatDialogFragment() {

    companion object {
        @JvmStatic
        fun showDialog(fragmentManager: FragmentManager, type: Int,
                       introduceData: ArrayList<IWillExchangeResponse.DataBean.KnowListBean>, title: String, price: String? = null): ExchangeDialog {
            val dialog = ExchangeDialog()
            val bundle = Bundle()
            bundle.putInt("type", type)
            bundle.putString("title", title)
            if (!TextUtils.isEmpty(price)) {
                bundle.putString("price", price)
            }
            bundle.putParcelableArrayList("introduceData", introduceData)
            dialog.arguments = bundle
            dialog.show(fragmentManager, "ExchangeDialog")
            return dialog
        }
    }

    //0 免费换电  1 紧急换电  2更换车辆
    private var type = 0
    // 支付方式 1：微信支付 2：支付宝支付
    private var payMethod = 1

    // 换电须知
    private var exchangeIntroduceData = arrayListOf<IWillExchangeResponse.DataBean.KnowListBean>()
    private var exchangeIntroduceAdapter: ExchangeIntroduceAdapter? = null
    private var title: String? = null
    private var price: String? = null

    override fun setContentView(): Int = R.layout.dialog_exchange

    override fun bindView() {
        setDialogBottom()

        bundle?.let {
            type = it.getInt("type")
            title = it.getString("title")
            price = it.getString("price")
            exchangeIntroduceData = it.getParcelableArrayList("introduceData")
        }

        when (type) {
            1 -> {
                exchangeNowPayment.visibility = View.GONE
                commonTipsTitle.text = title
                bottomViewOkLeftTv.text = "取消"
                bottomViewOkRightTv.text = "确认换电"
            }
            2 -> {
                commonTipsTitle.text = title
                exchangeNowPayment.visibility = View.GONE
                bottomViewOkLeftTv.text = "取消"
                bottomViewOkRightTv.text = "确认换电"
            }

            3 -> {
                bottomViewOkLeftTv.text = "取消"
                bottomViewOkRightTv.text = "确认支付"
                exchangeNowPayment.visibility = View.VISIBLE
                paymentTitleTextView.run {
                    if (!TextUtils.isEmpty(price)) {
                        text = "紧急换电费用：$price 元"
                    }
                    setTextColor(ToolBox.getColor(R.color.text_first_color))
                }
            }
            4 -> {
                commonTipsTitle.text = title
                exchangeNowPayment.visibility = View.GONE
                bottomViewOkLeftTv.text = "取消"
                bottomViewOkRightTv.text = "确认换电"
            }
        }


        setPayMethod(1)
        setViewClickDuration(wechatPayLayout, 1)
        setViewClickDuration(aliPayLayout, 1)
        setViewClickDuration(bottomViewOkLeftTv, 1)
        setViewClickDuration(bottomViewOkRightTv, 1)


        initRecyclerView()
    }

    private fun initRecyclerView() {
        activity?.let {
            exchangeIntroduceAdapter = ExchangeIntroduceAdapter(it, exchangeIntroduceData, R.layout.item_text_draw)
            commonTipsRecyclerView.layoutManager = LinearLayoutManager(it)
            commonTipsRecyclerView.adapter = exchangeIntroduceAdapter
            commonTipsRecyclerView.addItemDecoration(RecycleViewDivider(it, RecyclerView.VERTICAL, DensityUtil.dip2px(it, 10f), R.color.white_color))
        }

    }


    private fun setPayMethod(payWay: Int) {
        if (payWay == 1) {
            // 微信支付
            wechatSelectImageView.setImageResource(R.mipmap.selected_icon)
            aliSelectImageView.setImageResource(R.mipmap.unselected_icon)
        } else {
            // 支付宝支付
            aliSelectImageView.setImageResource(R.mipmap.selected_icon)
            wechatSelectImageView.setImageResource(R.mipmap.unselected_icon)
        }
        payMethod = payWay
    }

    override fun setViewClick(view: View?) {
        super.setViewClick(view)
        when (view) {
            wechatPayLayout -> setPayMethod(1)
            aliPayLayout -> setPayMethod(2)
            bottomViewOkLeftTv -> {
                iDialogCallback?.onCancel()
                dismiss()
            }
            bottomViewOkRightTv -> {
                iDialogCallback?.onConfirm(payMethod)
                dismiss()
            }
        }
    }

    override fun onCancel(dialog: DialogInterface?) {
        super.onCancel(dialog)
        iDialogCallback?.onCancel()
    }


    override fun getWidth(): Int = CommData.getScreen()[0]

    override fun getStyle(): Int = R.style.BottomAnimateDialog


    private var iDialogCallback: IDialogCallback? = null

    fun setiDialogCallback(iDialogCallback: IDialogCallback) {
        this.iDialogCallback = iDialogCallback
    }

    interface IDialogCallback {

        fun onConfirm(payMethod: Int)

        fun onCancel()
    }

}