package com.baojia.mebike.feature.exclusive.iWillExchange

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import android.text.TextUtils
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.baojia.mebike.R
import com.baojia.mebike.alipay.AliPayManager
import com.baojia.mebike.base.BaseActivity
import com.baojia.mebike.callback.IDialogCallback
import com.baojia.mebike.callback.PayListener
import com.baojia.mebike.data.response.exclusive.IWillExchangeResponse
import com.baojia.mebike.data.response.order.PayByOtherResponse
import com.baojia.mebike.feature.exclusive.detail.ExchangeDialog
import com.baojia.mebike.feature.exclusive.detail.ExchangeIntroduceAdapter
import com.baojia.mebike.feature.exclusive.nearBike.NearBikeActivity
import com.baojia.mebike.feature.exclusive.powerStation.PowerStationActivity
import com.baojia.mebike.feature.exclusive.shopping.changbattery.ChangeBatteryProgressAct
import com.baojia.mebike.util.DensityUtil
import com.baojia.mebike.util.Toast
import com.baojia.mebike.util.WechatPayUtils
import com.baojia.mebike.util.recyclerview.RecycleViewDivider
import kotlinx.android.synthetic.main.activity_iwill_exchange.*
import kotlinx.android.synthetic.main.layout_tips_common.*

class IwillExchangeActivity : BaseActivity(), IwillExchangeContract.View, PayListener {


    override fun layoutId(): Int = R.layout.activity_iwill_exchange

    override fun setTitle(): String = "我要换电"

    private val mData: ArrayList<IWillExchangeResponse.DataBean.ListBean> = arrayListOf()
    private val adapter = IwillExchangeAdapter(this, mData, R.layout.item_iwill_exchange)
    // 换电须知
    private val exchangeIntroduceData = arrayListOf<IWillExchangeResponse.DataBean.KnowListBean>()
    private var exchangeIntroduceAdapter: ExchangeIntroduceAdapter? = null

    private var mPresenter: IwillExchangeContract.Presenter? = null
    private var payMethod: Int = 0
    //0 免费上门换电  1 自行换电 2紧急上门换电  3 跟换车辆
    private var type = 0
    private var exchangeDialog: ExchangeDialog? = null
    // 车辆id
    private var bikeId: Int = 0

    override fun bindView(savedInstanceState: Bundle?) {

        intent?.let {
            bikeId = it.getIntExtra("bikeId", 0)
        }

        mPresenter = IwillExchangePresenter(this, this)

        iWillExchangeRcyclerView.layoutManager = LinearLayoutManager(this)
        iWillExchangeRcyclerView.adapter = adapter
        iWillExchangeRcyclerView.addItemDecoration(RecycleViewDivider(this, RecyclerView.VERTICAL, DensityUtil.dip2px(this, 15f), R.color.white_color))

        adapter.setOnItemClickListner { _, position ->
            run {

                if (mData[position].isExistChangeBattery == 1) {
                    ChangeBatteryProgressAct.openActivity(this@IwillExchangeActivity, mData[position].changeBatteryId, mData[position].id)
                    return@run
                }

                when (mData[position].flag) {
                    1 -> {
                        mData[position].isSelect = true
                        adapter.notifyItemChanged(position)
                        // 弹窗
                        var buttonCount = 1
                        if (mData[position].id == 1) {
                            buttonCount = 1
                        } else if (mData[position].id == 3) {
                            buttonCount = 2
                        }
                        val dialog = ExChangeTipsDialog.show(supportFragmentManager, "换电提示",
                                mData[position].flagDesc, buttonCount)
                        dialog.setDialogCallback(object : IDialogCallback() {
                            override fun onCancel() {
                                super.onCancel()
                                mData[position].isSelect = false
                                adapter.notifyItemChanged(position)
                            }

                            override fun onConfirm() {
                                super.onConfirm()
                                // 操作
                                showExchangeDialog(position)
                            }
                        })
                    }
                    0 -> {
                        mData[position].isSelect = true
                        adapter.notifyItemChanged(position)
                        // 正常
                        showExchangeDialog(position)
                    }
                }
            }
        }



        exchangeIntroduceAdapter = ExchangeIntroduceAdapter(this, exchangeIntroduceData, R.layout.item_text_draw)
        commonTipsRecyclerView.layoutManager = LinearLayoutManager(this)
        commonTipsRecyclerView.adapter = exchangeIntroduceAdapter
        commonTipsRecyclerView.addItemDecoration(RecycleViewDivider(this, RecyclerView.VERTICAL, DensityUtil.dip2px(this, 10f), R.color.white_color))
    }

    fun showExchangeDialog(position: Int) {
        exchangeDialog = ExchangeDialog.showDialog(supportFragmentManager, mData[position].id, mData[position].knowList,
                mData[position].knowListTitle, mData[position].amount.toString())

        exchangeDialog?.setiDialogCallback(object : ExchangeDialog.IDialogCallback {
            override fun onCancel() {
                mData[position].isSelect = false
                adapter.notifyItemChanged(position)
            }

            override fun onConfirm(payMethod: Int) {
                when (mData[position].id) {
                    1 -> {
                        mData[position].isSelect = false
                        adapter.notifyItemChanged(position)
                        // 普通上门换电
                        mPresenter?.exchangePower()
                    }
                    2 -> {
                        mData[position].isSelect = false
                        adapter.notifyItemChanged(position)
                        // 自行换电
                        PowerStationActivity.start(this@IwillExchangeActivity, bikeId)
                    }
                    3 -> {
                        mData[position].isSelect = false
                        adapter.notifyItemChanged(position)
                        // 紧急换电
                        this@IwillExchangeActivity.payMethod = payMethod
                        mPresenter?.payRequest()
                    }
                    4 -> {
                        mData[position].isSelect = false
                        adapter.notifyItemChanged(position)
                        // 更换车辆
                        startActivity(Intent(this@IwillExchangeActivity, NearBikeActivity::class.java))
                    }
                }
            }
        })
    }

    override fun onResume() {
        super.onResume()
        mPresenter?.getData()
        mPresenter?.checkOrderPayStatus()
    }

    override fun channelMethod(): Int = payMethod

    override fun wechatPay(dataBean: PayByOtherResponse.DataBean?) {
        WechatPayUtils.wechatPay(this, dataBean?.appid, dataBean?.partnerid, dataBean?.prepayid,
                dataBean?.wxpackage, dataBean?.noncestr, dataBean?.timestamp,
                dataBean?.sign)
    }

    override fun aliPay(dataBean: PayByOtherResponse.DataBean?) {
        AliPayManager(this)
                .alipayV2(this, dataBean?.orderInfo)
    }

    override fun setData(data: ArrayList<IWillExchangeResponse.DataBean.ListBean>?) {

        data?.let {
            mData.clear()
            mData.addAll(it)
            adapter.notifyDataSetChanged()
        }

    }

    override fun setIntroduceData(title: String?, data: ArrayList<IWillExchangeResponse.DataBean.KnowListBean>?) {
        exchangeIntroduceData.clear()
        data?.let {
            exchangeIntroduceData.addAll(it)
            exchangeIntroduceAdapter?.notifyDataSetChanged()
        }
        if (!TextUtils.isEmpty(title)) {
            commonTipsTitle.text = title
        }
    }


    override fun setPresenter(presenter: IwillExchangeContract.Presenter?) {
        this.setIPresenter(presenter)
    }

    override fun onSuccess() {

    }

    override fun onFailed(msg: String?) {
        msg?.run {
            Toast.show(this@IwillExchangeActivity, msg)
        }
    }

    override fun isVisibleTitleBar(): Boolean {
        return true
    }

    override fun getType(): Int = type

    override fun bikeId(): Int = bikeId


    companion object {
        @JvmStatic
        fun start(activity: Activity, bikeId: Int) {
            val intent = Intent(activity, IwillExchangeActivity::class.java)
            intent.putExtra("bikeId", bikeId)
            activity.startActivity(intent)
        }
    }
}