package com.baojia.mebike.feature.exclusive.iWillExchange

import android.text.TextUtils
import com.baojia.mebike.base.BasePresenter
import com.baojia.mebike.callback.HttpCallback
import com.baojia.mebike.config.Config
import com.baojia.mebike.data.response.BaseResponse
import com.baojia.mebike.data.response.exclusive.IWillExchangeResponse
import com.baojia.mebike.data.response.exclusive.SubmitChangeBatteryResponse
import com.baojia.mebike.data.response.order.PayByOtherResponse
import com.baojia.mebike.feature.exclusive.shopping.changbattery.ChangeBatteryProgressAct
import com.baojia.mebike.util.ToolBox

class IwillExchangePresenter(val activity: IwillExchangeActivity, val mView: IwillExchangeContract.View) : BasePresenter(activity), IwillExchangeContract.Presenter {


    private val model: IwillExchangeModel? = IwillExchangeModel(activity)

    private var orderNo: String? = null
    private var changeBatteryId: Long = 0

    override fun getData() {
        addDisposable(model?.getData(mView.bikeId(), object : HttpCallback<IWillExchangeResponse.DataBean>() {
            override fun onSucceed(data: IWillExchangeResponse.DataBean?) {
                super.onSucceed(data)

                mView?.setIntroduceData(data?.knowListTitle, data?.knowList)
                mView?.setData(data?.list)
            }
        }))

    }

    override fun payRequest() {
        var paymentType = 15
        if (ToolBox.isCompanyExclusive()) {
            paymentType = 15
        } else {
            paymentType = 17
        }
        addDisposable(model?.changePowerPrePay(mView.channelMethod(), paymentType, mView.bikeId(), object : HttpCallback<PayByOtherResponse.DataBean>() {
            override fun onSucceed(data: PayByOtherResponse.DataBean) {
                super.onSucceed(data)

                orderNo = data.orderNo
                changeBatteryId = data.changeBatteryId

                if (data.payChannelId == Config.CODE_PAYCHANNLID_WECHAT) {
                    // 微信支付
                    mView.wechatPay(data)
                } else if (data.payChannelId == Config.CODE_PAYCHANNLID_ALIPAY) {
                    // 支付宝支付
                    mView.aliPay(data)
                }
            }
        }))
    }

    override fun checkOrderPayStatus() {
        if (TextUtils.isEmpty(orderNo)) {
            return
        }
        addDisposable(model?.checkOrderPayStatus(orderNo, 4, object : HttpCallback<BaseResponse?>() {
            override fun onSucceed(data: BaseResponse?) {
                super.onSucceed(data)
                data?.let{
                    orderNo = null
                    if(changeBatteryId != null) {
                        // 跳转换电进度
                        ChangeBatteryProgressAct.openActivity(context, changeBatteryId, 3)
                    }
                }
            }

            override fun onFailed(code: Int, message: String) {
                super.onFailed(code, message)
            }
        }))
    }


    override fun exchangePower() {
        addDisposable(model?.submitChangeBatteryOrder(mView.bikeId(), object : HttpCallback<SubmitChangeBatteryResponse.DataBean>() {
            override fun onSucceed(data: SubmitChangeBatteryResponse.DataBean?) {
                super.onSucceed(data)
                // 换电成功
                ChangeBatteryProgressAct.openActivity(context, data?.id!!, 1)
            }
        }))
    }


}