package com.baojia.mebike.feature.exclusive.nearBike

import android.app.Activity
import android.view.LayoutInflater
import android.view.View
import android.widget.ImageView
import android.widget.TextView
import com.amap.api.maps.CameraUpdateFactory
import com.amap.api.maps.model.LatLng
import com.amap.api.maps.model.LatLngBounds
import com.amap.api.maps.model.Marker
import com.amap.api.services.core.LatLonPoint
import com.amap.api.services.route.RidePath
import com.amap.api.services.route.WalkPath
import com.baojia.mebike.R
import com.baojia.mebike.data.CommData
import com.baojia.mebike.data.response.MarkerBean
import com.baojia.mebike.map.AMapUtil
import com.baojia.mebike.map.GDMapView
import com.baojia.mebike.map.GDMapViewImp
import com.baojia.mebike.map.MapCallback
import com.baojia.mebike.map.miinterface.RideRouteOverlay
import com.baojia.mebike.map.miinterface.SearchRouteResultListener
import com.baojia.mebike.util.ToolBox

/**
 * +----------------------------------------------------------------------
 * | @time 2018/12/20:5:55 PM
 * | @author house
 * | @class_describe
 * +----------------------------------------------------------------------
 **/
class ExclusiveMapViewImp constructor(mapView: GDMapView, mContext: Activity) : GDMapViewImp(mapView, mContext),
        MapCallback.OnMarkerClickListener, MapCallback.OnMapClickListener, MapCallback.OnInfoWindowCallback,
        MapCallback.OnSearchRouteResultCallback {

    private var markerList = mutableMapOf<Int,Marker>()
    var mViewPaddingTop: Int = 0// 防止线路规划被挡住，下移高度
    var mViewPaddingBottom: Int = 0// 防止线路规划被挡住，上移高度
    private var mRideRouteOverlay: RideRouteOverlay? = null

    // 当前选中marker
    private var curSelectMarker: Marker? = null
    // Marker 是否可点击
    var isAppointmentSucceed = false

    init {
        mapView.setOnMarkerClickListener(this)
        mapView.setOnMapClickListener(this)
        mapView.setInfoWindowCallback(this)
        mapView.setOnSearchRouteResultCallback(this)
    }

    fun addLocation() {
        mapView.addLocationMarker(CommData.locationConfig.latLng)
    }

    /**
     * 设置预约数据
     */
    fun setAppointmentMarker(markerBean:MarkerBean) {
        if (curSelectMarker != null) {
            if(!markerList.containsValue(curSelectMarker!!)) {
                curSelectMarker!!.destroy()
                clearRouteOverlay()
            }
        }
        curSelectMarker = mapView.addMarker(LatLng(markerBean.latitude, markerBean.longitude),R.mipmap.bike_marker_select_icon, true)
        curSelectMarker?.let {
            it.`object` = markerBean
            it.setToTop()
            isAppointmentSucceed = true

            if (onMarkerClickListener != null) {
                onMarkerClickListener?.onMarkerClick(it)
            }
        }
    }

    /**
     * 清除预约数据
     */
    fun clearAppointmentMarker(){
        isAppointmentSucceed = false
        curSelectMarker?.let {
            if (onMapCancelListener != null) {
                onMapCancelListener?.onMapClick(it)
            }
            it.hideInfoWindow()
            if(markerList.containsValue(it)) {
                it.setIcon(AMapUtil.getBitmapDescriptor(R.mipmap.bike_marker_icon))
            } else {
                it.destroy()
            }
            null
        }


    }

    /**
     * 添加Marker
     * @param markerItemList
     */
    fun addMarker(markerItemList: ArrayList<MarkerBean>?) {

        Thread(Runnable {
            clearMarker()

            markerItemList?.let {
                for (markerBean in it) {
                    if (markerBean == null) {
                        continue
                    }

                    var icon = 0
                    if (markerBean.iconType == 1) {
                        icon = R.mipmap.bike_marker_icon
                    } else if (markerBean.iconType == 2) {
                        icon = R.mipmap.bike_marker_icon
                    }

                    val marker = mapView.addMarker(LatLng(markerBean.latitude, markerBean.longitude), icon, true)
                    if (marker != null) {
                        marker.`object` = markerBean
                        markerList[markerBean.bikeId] = marker
                    }

                    curSelectMarker?.setToTop()
                }
            }
        }).start()
    }

    /**
     * 是否存在marker
     */
    fun isHasMarkerById(bikeId:Int) : Marker? {
        for (entry in markerList){
            if(entry.key == bikeId) {
                return entry.value
            }
        }
        return null
    }

    override fun onMarkerClick(marker: Marker?) {
        if (isAppointmentSucceed) {
            return
        }
        setMarkerClick(marker)
    }

    fun setMarkerClick(marker:Marker?) {
        marker?.let {
            var markerBean = it.`object`
            if (markerBean != null) {
                markerBean = markerBean as MarkerBean

                if (markerBean != null) {
                    if (curSelectMarker != null) {
                        // 修改图标
                        curSelectMarker?.setIcon(AMapUtil.getBitmapDescriptor(R.mipmap.bike_marker_icon))
                    }

                    curSelectMarker = it

                    if (onMarkerClickListener != null) {
                        onMarkerClickListener?.onMarkerClick(it)
                    }
                }
            }
        }

    }

    override fun onMapClick(latLng: LatLng?) {

        if (isAppointmentSucceed) {
            return
        }

        curSelectMarker?.let {
            if (onMapCancelListener != null) {
                onMapCancelListener?.onMapClick(it)
            }

            clearRouteOverlay()
            it.setIcon(AMapUtil.getBitmapDescriptor(R.mipmap.bike_marker_icon))
            it.hideInfoWindow()
            null
        }
    }

    private var walkTime: Long = 0
    private var walkDistance: Double = 0.0

    override fun infoWindowView(marker: Marker): View? {
        var infoWindow: View? = null
        if (infoWindow == null) {
            infoWindow = LayoutInflater.from(mContext).inflate(
                    R.layout.main_wininfo, null)
        }

        val mWalkTimeTextView = infoWindow?.findViewById<TextView>(R.id.walkTimeTextView)
        val mWalkDistanceTextView = infoWindow?.findViewById<TextView>(R.id.walkDistanceTextView)
        val iconImageView = infoWindow?.findViewById<ImageView>(R.id.iconImageView)


        iconImageView?.setImageResource(R.mipmap.bicycle_infowindow_icon)
        mWalkTimeTextView?.text = (if (walkTime == 0L) 1 else walkTime).toString() + "分钟"
        if (walkDistance >= 1000) {
            mWalkDistanceTextView?.text = "${ToolBox.getTwoDecimal(walkDistance / 1000)}千米"
        } else {
            mWalkDistanceTextView?.text = "${ToolBox.getTwoDecimal(walkDistance)}米"
        }

        return infoWindow
    }

    override fun onInfoWindowClick(marker: Marker?) {

    }

    override fun onWalkSearchRouteResult(isSucess: Boolean, distance: Int, walkPath: WalkPath?, startPoint: LatLonPoint?,
                                         targetPoint: LatLonPoint?) {

    }

    override fun onRideSearchRouteResult(isSucess: Boolean, distance: Int, ridePath: RidePath?, startPoint: LatLonPoint?,
                                         targetPoint: LatLonPoint?) {

        clearRouteOverlay()
        mRideRouteOverlay = RideRouteOverlay(mContext, mapView.map, ridePath, startPoint, targetPoint)
        mRideRouteOverlay?.let {
            mRideRouteOverlay?.removeFromMap()
            mRideRouteOverlay?.addToMap()
            mRideRouteOverlay?.zoomToSpan(mViewPaddingTop, mViewPaddingBottom, null)

            walkTime = (ridePath?.duration as Long) / 60
            walkDistance = ridePath?.distance.toDouble()

            if (curSelectMarker != null) {
                curSelectMarker?.showInfoWindow()
            }

            mSearchRouteResultListener?.searchRouteResult(true, distance, curSelectMarker)
        }
    }

    //线路搜索结果回调
    private var mSearchRouteResultListener: SearchRouteResultListener? = null

    fun setSearchRouteResultListener(mSearchRouteResultListener: SearchRouteResultListener) {
        this.mSearchRouteResultListener = mSearchRouteResultListener
    }

    /**
     * 清空路线但不改变中心点坐标
     */
    fun clearRouteOverlay() {
        mRideRouteOverlay?.let {
            it?.removeFromMap()
            null
        }

    }

    fun clearMarker() {
        markerList?.let {
            for (map in markerList.entries) {
                map.value.destroy()
            }
            markerList.clear()
        }
    }

    /**
     * 移动到大头针位置
     */
    fun moveToLocationLatLng(mViewPaddingTop: Int, mViewPaddingBottom: Int) {

        val bound = LatLngBounds.builder()
        bound.include(CommData.locationConfig.latLng)

        mapView.map?.animateCamera(CameraUpdateFactory.newLatLngBoundsRect(bound.build(),
                0, mViewPaddingTop, 0, mViewPaddingBottom))
    }

    /**
     * 路线规划
     */
    fun searchRouteResult() {
        curSelectMarker?.let {
            val position = it.position ?: return

            it.setIcon(AMapUtil.getBitmapDescriptor(R.mipmap.bike_marker_select_icon))
            mapView.searchRouteResult(GDMapView.ROUTE_TYPE_ROUTE, LatLonPoint(CommData.locationConfig.latLng.latitude,
                    CommData.locationConfig.latLng.longitude), LatLonPoint(position.latitude, position.longitude), false)
        }

    }

    private var onMarkerClickListener: MapCallback.OnMarkerClickListener? = null

    fun setOnMarkerClickListener(onMarkerClickListener: MapCallback.OnMarkerClickListener) {
        this.onMarkerClickListener = onMarkerClickListener
    }

    private var onMapCancelListener: MapCallback.OnMapCancelListener? = null

    fun setOnMapCancelListener(onMapCancelListener: MapCallback.OnMapCancelListener) {
        this.onMapCancelListener = onMapCancelListener
    }


}