package com.baojia.mebike.feature.exclusive.nearBike

import android.animation.Animator
import android.animation.AnimatorListenerAdapter
import android.os.Bundle
import android.os.CountDownTimer
import android.view.View
import com.amap.api.maps.model.Marker
import com.baojia.mebike.R
import com.baojia.mebike.base.BaseActivity
import com.baojia.mebike.data.CommData
import com.baojia.mebike.data.response.MarkerBean
import com.baojia.mebike.data.response.bike.BikeDetailsResponse
import com.baojia.mebike.dialog.RouteLoading
import com.baojia.mebike.dialog.SelectMapDialog
import com.baojia.mebike.map.MapCallback
import com.baojia.mebike.map.miinterface.SearchRouteResultListener
import com.baojia.mebike.util.AnimatorUtils
import com.baojia.mebike.util.DensityUtil
import com.baojia.mebike.util.JumpActivity
import kotlinx.android.synthetic.main.activity_near_bike.*

/**
 * +----------------------------------------------------------------------
 * | @time 2018/12/20:11:07 PM
 * | @author house
 * | @class_describe 附近专属车辆
 * +----------------------------------------------------------------------
 **/
class NearBikeActivity : BaseActivity(), NearBikeContract.View, MapCallback.OnMarkerClickListener, MapCallback.OnMapCancelListener,
        SearchRouteResultListener {

    private var mPresenter: NearBikePresenter? = null

    private var mapViewImp: ExclusiveMapViewImp? = null

    private var bikeId: Int = 0

    private var loadingDialog: RouteLoading? = null

    private var gdLongitude: Double = 0.0
    private var gdLatitude: Double = 0.0

    private var bikeDetailsData: BikeDetailsResponse.DataBean? = null

    override fun layoutId(): Int {
        return R.layout.activity_near_bike
    }

    override fun bindView(savedInstanceState: Bundle?) {

        mapView.onCreate(savedInstanceState)
        mapViewImp = ExclusiveMapViewImp(mapView, this@NearBikeActivity)

        bikeId = intent.getIntExtra("bikeId", 0)

        titleView.text = "查看附近可换车辆"

        setViewClickDuration(appointmentImageView, 1)
        setViewClickDuration(navigationImageView, 1)
        setViewClickDuration(whistleImageView, 1)
        setViewClickDuration(changeBikeImageView, 1)
        setViewClickDuration(backButton, 1)

        mapViewImp?.let {
            it.mViewPaddingBottom = DensityUtil.getViewHeight(cardView) + DensityUtil.dip2px(this, 15f)
            it.moveToLocationLatLng(0, 0)
            it.addLocation()
            it.setOnMapCancelListener(this)
            it.setOnMarkerClickListener(this)
            it.setSearchRouteResultListener(this)
        }

        mPresenter = NearBikePresenter(this, this)

        mPresenter?.searchBike()
    }


    override fun onResume() {
        super.onResume()
        mapViewImp?.onResume()
        mPresenter?.getProcessingOrder()
    }

    override fun onPause() {
        super.onPause()
        mapViewImp?.onPause()
    }

    override fun onDestroy() {
        super.onDestroy()
        mapViewImp?.onDestroy()
    }


    override fun setPresenter(presenter: NearBikeContract.Presenter?) {
        this.setIPresenter(presenter)
    }

    override fun drawBikeMarker(markerItemList: ArrayList<MarkerBean>) {
        mapViewImp?.addMarker(markerItemList)
    }

    override fun onMarkerClick(marker: Marker?) {
        try {
            val markerBean: MarkerBean = marker?.`object` as MarkerBean
            markerBean?.let {
                // 获取车辆详情
                this.bikeId = it.bikeId
                if (mPresenter?.isAppointment() == false) {
                    mPresenter?.getBikeDetails()
                } else {
                    setBikeDetails(bikeDetailsData)
                }
            }
        } catch (e: Throwable) {

        }

    }

    override fun onMapClick(marker: Marker?) {
        dismissInfoView()
        mapViewImp?.clearRouteOverlay()
    }


    override fun setViewClick(view: View?) {
        super.setViewClick(view)
        when (view?.id) {
            R.id.appointmentImageView -> {
                // 预约
                if (mPresenter?.isAppointment() == true) {
                    mPresenter?.cancelAppointment()
                    return
                }
                mPresenter?.appointment()
            }
            R.id.navigationImageView -> {
                // 导航
                SelectMapDialog.show(this, supportFragmentManager, gdLatitude, gdLongitude)
            }
            R.id.whistleImageView -> {
                // 鸣笛
                mPresenter?.findBikeAndWhistle()
            }
            R.id.changeBikeImageView -> {
                // 扫码换车
                JumpActivity.JumpScanActivity(this, 3)
            }
            R.id.backButton -> {
                finish()
            }
        }
    }

    override fun bikeId(): Int {
        return bikeId
    }

    override fun setAppointmentData(shutdownTime: Int, bikeId: Int) {
        mapViewImp?.isAppointmentSucceed = true
        countDownTimer(shutdownTime * 1000L)
    }

    override fun isHaveBikeMarker(shutdownTime: Int, bikeId: Int) {
        var marker = mapViewImp?.isHasMarkerById(bikeId)
        countDownTimer(shutdownTime * 1000L)
        mapViewImp?.isAppointmentSucceed = true
        if (marker != null) {
            // 存在marker
            if (cardView.visibility == View.GONE) {
                // 没有显示
                mapViewImp?.setMarkerClick(marker)
            }
        } else {
            this.bikeId = bikeId
            mPresenter?.getBikeDetails(2)
        }
    }

    override fun setAppointmentMarker(shutdownTime: Int, markerBean: MarkerBean?, bikeDetailsData: BikeDetailsResponse.DataBean?) {
        markerBean?.let {
            this.bikeDetailsData = bikeDetailsData
            mapViewImp?.isAppointmentSucceed = true
            countDownTimer(shutdownTime * 1000L)
            var marker = mapViewImp?.isHasMarkerById(it.bikeId)
            if (marker != null) {
                // 存在marker
                if (cardView.visibility == View.GONE) {
                    // 没有显示
                    mapViewImp?.setMarkerClick(marker)
                }
            } else {
                mapViewImp?.setAppointmentMarker(it)
                this.bikeId = bikeId
            }
        }
    }

    private var countDownTimer: CountDownTimer? = null
    /**
     * 倒计时
     */
    private fun countDownTimer(timer: Long) {
        if (countDownTimer == null) {
            countDownTimer = object : CountDownTimer(timer, 1000) {
                override fun onTick(l: Long) {
                    // 算分钟
                    var time = l / 1000 / 60
                    if (time < 1) {
                        time = 1
                    }
                    appointmentIntroduceTextView.text = "$time 分钟后自动取消"
                }

                override fun onFinish() {
                    cancelDownTimer()
                    mPresenter?.cancelAppointment()
                }
            };
        }
        countDownTimer?.let {
            it.start()
            appointmentTextView.text = "取消预约"
        }
    }

    private fun cancelDownTimer() {
        countDownTimer?.cancel()
        countDownTimer = null
        appointmentTextView.text = "预约"
        appointmentIntroduceTextView.text = "可锁定车辆1小时"
    }

    override fun cancelAppointmentSucceed() {
        appointmentIntroduceTextView.text = "可锁定车辆1小时"
        appointmentTextView.text = "预约"
        mapViewImp?.clearAppointmentMarker()
        cancelDownTimer()
    }

    override fun showLoadingDialog() {
        if (loadingDialog == null) {
            loadingDialog = RouteLoading(this)
        }
        if (loadingDialog?.isShowing == false) {
            loadingDialog?.show()
        }
    }

    override fun dismissLoadingDialog() {
        loadingDialog?.let {
            if (it.isShowing) {
                it.dismiss()
            }
        }
    }

    override fun setBikeDetails(data: BikeDetailsResponse.DataBean?) {
        data?.let {
            showInfoView()
            introduceTextView.text = "车辆编号：${it.plateNo}"
            batteryTextView.text = "${it.batteryLevel}%"
            when {
                it.batteryLevel < 30 -> batteryIcon.setImageResource(R.mipmap.battery_red_icon)
                it.batteryLevel < 70 -> batteryIcon.setImageResource(R.mipmap.battery_yellow_icon)
                else -> batteryIcon.setImageResource(R.mipmap.battery_green_icon)
            }
            mapViewImp?.searchRouteResult()
            if (it.centerLocation != null && it.centerLocation.size > 1) {
                gdLongitude = it.centerLocation[0]
                gdLatitude = it.centerLocation[1]
            }
        }
    }

    override fun searchRouteResult(isSucess: Boolean, distance: Int, marker: Marker?) {
        dismissLoadingDialog()
    }

    /**
     * 显示信息
     */
    private fun showInfoView() {
        AnimatorUtils.verticalTranslation(cardView, 200, (CommData.getScreen()[1] - DensityUtil.getViewHeight(cardView)).toFloat(),
                0f)
        cardView.visibility = View.VISIBLE
    }

    /**
     * 隐藏信息
     */
    private fun dismissInfoView() {
        val animator = AnimatorUtils.verticalTranslation(cardView, 200, 0f,
                (CommData.getScreen()[1] - DensityUtil.getViewHeight(cardView)).toFloat())
        animator.addListener(object : AnimatorListenerAdapter() {
            override fun onAnimationEnd(animation: Animator?) {
                cardView.visibility = View.GONE
            }
        })
        if (mPresenter?.isAppointment() == false) {
            appointmentTextView.text = "预约"
            appointmentIntroduceTextView.text = "可锁定车辆1小时"
        }
    }
}