package com.baojia.mebike.feature.exclusive.nearBike

import android.app.Activity
import android.text.TextUtils
import com.baojia.mebike.R
import com.baojia.mebike.base.BasePresenter
import com.baojia.mebike.base.aboutbike.AboutBikeModel
import com.baojia.mebike.callback.HttpCallback
import com.baojia.mebike.data.CommData
import com.baojia.mebike.data.SubmitOrderData
import com.baojia.mebike.data.response.BaseResponse
import com.baojia.mebike.data.response.MarkerBean
import com.baojia.mebike.data.response.bike.BikeDetailsResponse
import com.baojia.mebike.data.response.bike.ProcessingOrderResponse
import com.baojia.mebike.data.response.bike.SendBoxInstructResponse
import com.baojia.mebike.data.response.main.SearchBikeResponse
import com.baojia.mebike.feature.main.dialog.RingWhistleDialog
import com.baojia.mebike.util.CollectionsWrapper
import com.baojia.mebike.util.Toast

/**
 * +----------------------------------------------------------------------
 * | @time 2018/12/22:5:40 PM
 * | @author house
 * | @class_describe
 * +----------------------------------------------------------------------
 **/
class NearBikePresenter constructor(var mContext: Activity, var mView: NearBikeContract.View) : BasePresenter(mContext),
        NearBikeContract.Presenter {


    private var nearBikeModel: AboutBikeModel? = null

    private var orderNo: String? = null

    private var isAppointment: Boolean = false

    private var remainSecond: Int = 0

    init {
        nearBikeModel = AboutBikeModel(mContext)
    }

    override fun searchBike() {

        nearBikeModel?.knightSearchNearBike(object : HttpCallback<SearchBikeResponse.DataBean>() {
            override fun onSucceed(response: SearchBikeResponse.DataBean?) {
                if (SubmitOrderData.isAppointment) {
                    return
                }

                response?.let {
                    if (CollectionsWrapper.isEmpty(it.bikeVos)) {
                        Toast.show(mContext, R.string.no_car)
                        return
                    }

                    val list = it.bikeVos
                    val markerBeanList = ArrayList<MarkerBean>()
                    for (listBean in list) {
                        if (null != listBean.centerLocation && listBean.centerLocation.size > 1) {
                            val markerBean = MarkerBean()
                            markerBean.latitude = listBean.centerLocation[1]
                            markerBean.longitude = listBean.centerLocation[0]
                            markerBean.setIsPrice0(listBean.is0RMB)
                            markerBean.setIsHalfPrice(listBean.halfPriceType)
                            markerBean.plateNo = listBean.plateNo
                            markerBean.operationId = listBean.operateAreaId
                            markerBean.bikeId = listBean.bikeId
                            markerBean.discount = listBean.discount
                            markerBean.iconType = 1
                            markerBeanList.add(markerBean)
                        }
                    }
                    mView.drawBikeMarker(markerBeanList)
                }
            }

            override fun onFailed(code: Int, errorMsg: String) {
                if (!TextUtils.isEmpty(errorMsg)) {
                    Toast.show(context, errorMsg)
                }
            }
        })
    }

    override fun getProcessingOrder() {
        nearBikeModel?.getKnightProcessingOrder(2, object : HttpCallback<ProcessingOrderResponse>() {
            override fun onSucceed(data: ProcessingOrderResponse?) {
                super.onSucceed(data)
                data?.let {
                    isAppointment = false
                    if (it.data.orderStatus == 100) {
                        // 预约
                        remainSecond = it.data.remainSecond

                        if (remainSecond <= 0) {
                            return
                        }
                        isAppointment = true
                        mView.isHaveBikeMarker(remainSecond, it.data.bikeId)
                        orderNo = it.data.orderNo
                    }
                }
            }
        })
    }

    override fun appointment() {
        if (isAppointment) {
            return
        }
        nearBikeModel?.knightAppointmentOrder(mView.bikeId(), 2) { orderNo, timer ->
            if (TextUtils.isEmpty(orderNo)) {
                if (isAppointment) {
                    isAppointment = false
                    mView.cancelAppointmentSucceed()
                }
            } else {
                mView.setAppointmentData(timer, mView.bikeId())
                this.orderNo = orderNo
                isAppointment = true
            }
        }
    }

    override fun cancelAppointment() {
        nearBikeModel?.knightCancelOrder(orderNo, object : HttpCallback<BaseResponse>() {
            override fun onSucceed(data: BaseResponse?) {
                super.onSucceed(data)
                data?.let {
                    isAppointment = false
                    orderNo = null
                    mView.cancelAppointmentSucceed()
                }
            }

            override fun onFailed(code: Int, message: String?) {
                super.onFailed(code, message)
                Toast.show(mContext,message)
            }

            override fun onError(code: Int, message: String?) {
                super.onError(code, message)
                onFailed(code,message)
            }
        })
    }


    override fun findBikeAndWhistle() {
        nearBikeModel?.sendBoxInstruct("C", mView.bikeId(), null, null, true,
                object : HttpCallback<SendBoxInstructResponse>() {
                    override fun onSucceed(data: SendBoxInstructResponse?) {
                        super.onSucceed(data)
                        if (data?.data == null) {
                            Toast.show(context, data?.message)
                            return
                        }
                        val ringWhistleDialog = RingWhistleDialog(mContext)
                        ringWhistleDialog.show()
                    }
                })
    }

    override fun getBikeDetails(reserveType:Int) {
        mView?.showLoadingDialog()
        nearBikeModel?.getBikeDetails(CommData.locationConfig.latLng.latitude, CommData.locationConfig.latLng.longitude,
                mView.bikeId().toString(), 1,reserveType,0, false, object : HttpCallback<BikeDetailsResponse.DataBean>() {
            override fun onSucceed(data: BikeDetailsResponse.DataBean?) {
                super.onSucceed(data)
                if (isAppointment) {
                    // 设置预约marker
                    data?.let {
                        val markerBean = MarkerBean()
                        markerBean.latitude = it.centerLocation[1]
                        markerBean.longitude = it.centerLocation[0]
                        markerBean.setIsPrice0(it.is0RMB)
                        markerBean.setIsHalfPrice(it.halfPriceType)
                        markerBean.plateNo = it.plateNo
                        markerBean.operationId = it.operateAreaId
                        markerBean.bikeId = it.bikeId
                        markerBean.discount = it.discount
                        markerBean.iconType = 1

                        mView.setAppointmentMarker(remainSecond, markerBean,data)
                    }

                    return
                }

                mView.setBikeDetails(data)
            }

            override fun onFailed(code: Int, message: String?) {
                super.onFailed(code, message)
                mView?.dismissLoadingDialog()

            }
        })
    }

    override fun isAppointment(): Boolean {
        return isAppointment
    }
}