package com.baojia.mebike.feature.exclusive.powerStation

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import android.view.View
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.amap.api.maps.model.Marker
import com.baojia.mebike.R
import com.baojia.mebike.base.BaseActivity
import com.baojia.mebike.data.CommData
import com.baojia.mebike.data.response.exclusive.PowerStationResponse
import com.baojia.mebike.dialog.SelectMapDialog
import com.baojia.mebike.map.MapCallback
import com.baojia.mebike.util.DensityUtil
import com.baojia.mebike.util.JumpActivity
import com.baojia.mebike.util.ToolBox
import com.baojia.mebike.util.recyclerview.RecycleViewDivider
import com.google.android.material.bottomsheet.BottomSheetBehavior
import kotlinx.android.synthetic.main.activity_check_near_power_station.*


/**
 * +----------------------------------------------------------------------
 * | @time 2018/12/20:3:50 PM
 * | @author house
 * | @class_describe
 * +----------------------------------------------------------------------
 **/
class PowerStationActivity : BaseActivity(), PowerStationContract.View, MapCallback.OnMarkerClickListener,
        MapCallback.OnMapCancelListener, View.OnClickListener {


    companion object {

        fun start(context: Activity, bikeId: Int) {
            val intent = Intent(context, PowerStationActivity::class.java)
            intent.putExtra("bikeId", bikeId)
            context.startActivity(intent)
        }
    }

    private var mPresenter: PowerStationContract.Presenter? = null


    private var mBottomSheetBehavior: BottomSheetBehavior<View>? = null
    private var mapViewImp: PowerStationMapViewImp? = null
    private var powerStationAdapter: PowerStationAdapter? = null
    private val siteList: ArrayList<PowerStationResponse.DataBean.BatteryReplaceSiteVoListBean> = arrayListOf()

    private var curSelectData: PowerStationResponse.DataBean.BatteryReplaceSiteVoListBean? = null

    private var bikeId: Int = 0

    override fun layoutId(): Int {
        return R.layout.activity_check_near_power_station
    }

    override fun bindView(savedInstanceState: Bundle?) {

        titleView.text = "查看附近换电站"

        bikeId = intent.getIntExtra("bikeId", 0)

        mapView.onCreate(savedInstanceState)
        mapViewImp = PowerStationMapViewImp(mapView, this)



        mBottomSheetBehavior = BottomSheetBehavior.from(bottomLayout)
        mBottomSheetBehavior?.state = BottomSheetBehavior.STATE_COLLAPSED
        mBottomSheetBehavior?.setBottomSheetCallback(mBottomSheetBehaviorCallback)

        mapViewImp?.let {
            it.mViewPaddingBottom = DensityUtil.getViewHeight(navigationBackgroundImageView) + DensityUtil.dip2px(this, 15f)
            it.addLocation()
            it.moveToLocationLatLng(0, 0)
            it.setOnMapCancelListener(this)
            it.setOnMarkerClickListener(this)
        }

        mPresenter = PowerStationPresenter(this, this)

        setRecyclerView()

        callButton.setOnClickListener(this)
        backButton.setOnClickListener(this)
        navigationButton.setOnClickListener(this)
        backBottomButton.setOnClickListener(this)
        navigationBackgroundImageView.setOnClickListener(this)

        mPresenter?.searchPowerStation()

    }

    private fun setRecyclerView() {
        siteInfoRecyclerView.layoutManager = LinearLayoutManager(this)
        powerStationAdapter = PowerStationAdapter(this, siteList, R.layout.item_power_station)
        siteInfoRecyclerView.adapter = powerStationAdapter
        siteInfoRecyclerView.addItemDecoration(RecycleViewDivider(this, RecyclerView.VERTICAL, DensityUtil.dip2px(this, 1f), R.color.line_color))

        powerStationAdapter?.let {
            it.setOnItemClickListner { _, position ->
                mapViewImp?.setCurSelectMarker(siteList[position].id)
                curSelectData = siteList[position]
            }
        }

    }

    override fun onResume() {
        super.onResume()
        mapViewImp?.onResume()
    }

    override fun onPause() {
        super.onPause()
        mapViewImp?.onPause()
    }

    override fun onDestroy() {
        super.onDestroy()
        mapViewImp?.onDestroy()
    }


    /**
     * 显示底部导航信息
     */
    private fun setNavigationInfoVisible(isShow: Boolean) {
        var isVisible: Int
        if (isShow) {
            isVisible = View.VISIBLE
        } else {
            isVisible = View.GONE
        }
        navigationBackgroundImageView.visibility = isVisible
        locationIconImageView.visibility = isVisible
        navigationButton.visibility = isVisible
        callButton.visibility = isVisible
        addressTextView.visibility = isVisible
        distanceTextView.visibility = isVisible
        lineImageView.visibility = isVisible
        navigationIntroduceTextView.visibility = isVisible
    }


    private val mBottomSheetBehaviorCallback = object : BottomSheetBehavior.BottomSheetCallback() {

        override fun onStateChanged(bottomSheet: View, newState: Int) {
            if (powerStationBehaviorLayout.visibility == View.VISIBLE) {
                topLayout.visibility = View.VISIBLE
            } else {
                topLayout.visibility = View.INVISIBLE
            }
        }

        override fun onSlide(bottomSheet: View, slideOffset: Float) {
            if (powerStationBehaviorLayout.visibility == View.VISIBLE) {
                topLayout.visibility = View.VISIBLE
            } else {
                topLayout.visibility = View.INVISIBLE
            }
        }
    }

    override fun setPresenter(presenter: PowerStationContract.Presenter?) {
        this.setIPresenter(presenter)
    }

    override fun drawSitMarker(markerBeanList: ArrayList<PowerStationResponse.DataBean.BatteryReplaceSiteVoListBean>) {
        //    //设置初始化高度

        siteList.clear()
        siteList.addAll(markerBeanList)
        powerStationAdapter?.notifyDataSetChanged()

        mapViewImp?.addSiteMarker(markerBeanList)
        val height = CommData.getScreen()[1] * 242 / 667
        mBottomSheetBehavior?.peekHeight = height

        mBottomSheetBehavior?.state = BottomSheetBehavior.STATE_COLLAPSED

    }

    override fun onMarkerClick(marker: Marker?) {
        // 底部列表隐藏，底部信息栏显示
        setNavigationInfoVisible(true)
//        mBottomSheetBehavior?.state = BottomSheetBehavior.STATE_HIDDEN
        bottomLayout.visibility = View.GONE
        curSelectData = marker?.`object` as PowerStationResponse.DataBean.BatteryReplaceSiteVoListBean

        curSelectData?.let {
            addressTextView.text = it.siteName
            navigationIntroduceTextView.text = it.address
            if (it.distance >= 1000) {
                distanceTextView.text = "${ToolBox.getTwoDecimal(it.distance / 1000)}km"
            } else {
                distanceTextView.text = "${ToolBox.getTwoDecimal(it.distance)}m"
            }
        }
    }

    override fun bikeId(): Int = bikeId


    override fun onMapClick(marker: Marker?) {
        // 清除路线规划，底部列表显示
        setNavigationInfoVisible(false)
        mBottomSheetBehavior?.state = BottomSheetBehavior.STATE_COLLAPSED
        bottomLayout.visibility = View.VISIBLE
    }

    override fun onClick(v: View?) {
        when (v) {
            callButton -> {
                JumpActivity.JumpToCallPhone(this, curSelectData?.mobile)
            }
            navigationButton -> {
                SelectMapDialog.show(this, supportFragmentManager, curSelectData?.latitude
                        ?: 0.0, curSelectData?.longitude ?: 0.0)
            }
            backButton -> {
                finish()
            }
            backBottomButton -> {
                mBottomSheetBehavior?.state = BottomSheetBehavior.STATE_COLLAPSED
            }
            navigationBackgroundImageView -> {

            }
        }
    }
}