package com.baojia.mebike.feature.exclusive.shopping.buyBikeConfig

import android.app.Activity
import com.baojia.mebike.R
import com.baojia.mebike.callback.HttpCallback
import com.baojia.mebike.data.response.exclusive.shapping.BuyBikeConfigResponse
import com.baojia.mebike.data.response.exclusive.shapping.BuyConfigCommitResponse
import com.baojia.mebike.data.response.order.PayByOtherResponse
import com.baojia.mebike.feature.model.PayModel
import com.baojia.mebike.http.HttpUtils
import com.baojia.mebike.util.Toast
import io.reactivex.disposables.Disposable

class BuyBikeConfigModel(activity: Activity) : PayModel(activity) {

    private val BUY_CONFIG_COMMIT = "/pmall/create/order"
    private val BUY_PAY_DETAIL = "/pmall/pre/pay/order"
    private val URL_BUY_BIKE_CONFIG = "/pmall/get/packages"
    private val URL_BUY_BIKE_PAY = "/pmall/order/pay"

    /**
     *
     */
    fun buyConfigCommit(goodsType: Int, goodsId: Int, productId: Int, productColorId: Int,
                        packageItemIds: String, takeType: Int, takeUserName: String,
                        takeUserPhone: String, takeUserAddrRemarks: String,
                        takeUserAddr: String, takeLatitude :Double ,takeLongitude : Double,httpCallback: HttpCallback<BuyConfigCommitResponse>?): Disposable? {
        val params = HashMap<String, Any>()
        params["goodsId"] = goodsId
        params["productId"] = productId
        params["goodsType"] = goodsType
        params["productColorId"] = productColorId
        params["packageItemIds"] = packageItemIds
        params["takeType"] = takeType
        params["takeUserName"] = takeUserName
        params["takeUserPhone"] = takeUserPhone
        params["takeUserAddrRemarks"] = takeUserAddrRemarks
        params["takeUserAddr"] = takeUserAddr
        params["takeLatitude"] = if (takeLatitude.equals(0)) "" else takeLatitude
        params["takeLongitude"] = if (takeLongitude.equals(0)) "" else takeLongitude
        return HttpUtils.postRequest(activity, BUY_CONFIG_COMMIT, params, true, object : HttpCallback<BuyConfigCommitResponse>() {
            override fun onSucceed(data: BuyConfigCommitResponse?) {
                super.onSucceed(data)
                data?.let {
                    httpCallback?.onSucceed(it)
                }
            }

            override fun onFailed(code: Int, message: String) {
                super.onFailed(code, message)
                Toast.show(activity, message)
            }

            override fun onError(code: Int, message: String) {
                super.onError(code, message)
                onFailed(code, message)
            }
        }, BuyConfigCommitResponse::class.java)
    }

    fun payDetailData(orderNo: String, httpCallback: HttpCallback<BuyConfigCommitResponse>?): Disposable? {
        val params = HashMap<String, Any>()
        params["orderNo"] = orderNo
        return HttpUtils.postRequest(activity, BUY_PAY_DETAIL, params, true, object : HttpCallback<BuyConfigCommitResponse>() {
            override fun onSucceed(data: BuyConfigCommitResponse?) {
                super.onSucceed(data)
                data?.let {
                    httpCallback?.onSucceed(it)
                }
            }

            override fun onFailed(code: Int, message: String) {
                super.onFailed(code, message)
                Toast.show(activity, message)
            }

            override fun onError(code: Int, message: String) {
                super.onError(code, message)
                onFailed(code, message)
            }
        }, BuyConfigCommitResponse::class.java)
    }

    fun getAllData(productId: Int, goodsId: Int, httpCallback: HttpCallback<BuyBikeConfigResponse>): Disposable {

        val params: Map<String, Any> = mapOf("productId" to productId, "goodsId" to goodsId)

        return HttpUtils.postRequest(activity, URL_BUY_BIKE_CONFIG, params, true, httpCallback, BuyBikeConfigResponse::class.java)
    }


    fun orderPay(orderNo: String,payMethod: Int, httpCallback: HttpCallback<PayByOtherResponse.DataBean>?): Disposable {

        val params = java.util.HashMap<String, Any>()
        params["orderNo"] = orderNo
        params["payMethod"] = payMethod
        params["paymentType"] = 16
        return HttpUtils.postRequest(activity, URL_BUY_BIKE_PAY, params, object : HttpCallback<PayByOtherResponse>() {
            override fun onSucceed(data: PayByOtherResponse?) {
                super.onSucceed(data)
                data?:return
                if (data.data == null) {
                    Toast.show(activity, R.string.json_error)
                    return
                }
                httpCallback?.onSucceed(data.data)
            }

            override fun onFailed(code: Int, message: String) {
                super.onFailed(code, message)
                Toast.show(activity, message)
                if (code == 121) {
                    // 已支付
                    httpCallback?.onFailed(code, message)
                } else if (code == 187) {
                    // 已充值
                }
            }

            override fun onError(code: Int, message: String) {
                super.onError(code, message)
                onFailed(code, message)
            }
        }, PayByOtherResponse::class.java)
    }

}