package com.baojia.mebike.feature.exclusive.shopping.nearBike

import android.app.Activity
import android.os.Handler
import android.view.LayoutInflater
import android.view.View
import android.widget.ImageView
import android.widget.TextView
import com.amap.api.maps.AMap
import com.amap.api.maps.AMapUtils
import com.amap.api.maps.CameraUpdateFactory
import com.amap.api.maps.model.BitmapDescriptorFactory
import com.amap.api.maps.model.LatLng
import com.amap.api.maps.model.LatLngBounds
import com.amap.api.maps.model.Marker
import com.amap.api.services.core.LatLonPoint
import com.amap.api.services.route.RidePath
import com.amap.api.services.route.WalkPath
import com.baojia.mebike.R
import com.baojia.mebike.config.MapViewConfig.*
import com.baojia.mebike.data.CommData
import com.baojia.mebike.data.response.MarkerBean
import com.baojia.mebike.map.*
import com.baojia.mebike.map.miinterface.RideRouteOverlay
import com.baojia.mebike.map.miinterface.SearchRouteResultListener
import com.baojia.mebike.util.ToolBox

/**
 * +----------------------------------------------------------------------
 * | @time 2018/12/20:5:55 PM
 * | @author house
 * | @class_describe
 * +----------------------------------------------------------------------
 **/
class ExclusiveMapViewImp constructor(mapView: GDMapView, mContext: Activity, val intentType: Int) : ReturnAreaMapImp(mapView, mContext),
        MapCallback.OnMarkerClickListener, MapCallback.OnMapClickListener, MapCallback.OnInfoWindowCallback,
        MapCallback.OnSearchRouteResultCallback, MapCallback.OnMapStableCallback {


    private var markerList = mutableMapOf<Int, Marker>()
    var mViewPaddingTop: Int = 0// 防止线路规划被挡住，下移高度
    var mViewPaddingBottom: Int = 0// 防止线路规划被挡住，上移高度
    private var mRideRouteOverlay: RideRouteOverlay? = null

    // 当前选中marker
    private var curSelectMarker: Marker? = null
    // Marker 是否可点击
    var isAppointmentSucceed = false

    private var lastTime: Long = 0
    private var mHandler: Handler? = null

    // 刷新距离
    private var refreshDistance = 500
    // 是否可以刷新
    var isRefreshEnable: Boolean = true

    // 当前大头针坐标
    private var mCurLatlng: LatLng? = null
    // 最后打头阵定位点
    private var mLastLatlng: LatLng? = null

    private var mRefreshMapMoveListener: RefreshMapMoveListener? = null//移动一定距离和时间 刷新数据
    private var onAnimatorCallback: MapCallback.OnAnimatorCallback? = null

    init {
        mHandler = Handler()
        mapView.setMapStableCallback(this)
        // 默认不可点击
        if (intentType > 0) {
            mapView.setOnMarkerClickListener(this)
            mapView.setOnMapClickListener(this)
            mapView.setInfoWindowCallback(this)
            mapView.setOnSearchRouteResultCallback(this)
        }
    }

    fun addLocation() {
        mapView.addLocationMarker(CommData.locationConfig.latLng)
        mCurLatlng = CommData.locationConfig.latLng
    }

    /**
     * 设置预约数据
     */
    fun setAppointmentMarker(markerBean: MarkerBean) {
        if (curSelectMarker != null) {
            if (!markerList.containsValue(curSelectMarker!!)) {
                curSelectMarker!!.destroy()
                clearRouteOverlay()
            }
        }
        curSelectMarker = mapView.addMarker(LatLng(markerBean.latitude, markerBean.longitude), R.mipmap.bike_marker_select_icon, true)
        curSelectMarker?.let {
            it.`object` = markerBean
            it.setToTop()
            isAppointmentSucceed = true

            if (onMarkerClickListener != null) {
                onMarkerClickListener?.onMarkerClick(it)
            }
        }
    }

    /**
     * 清除预约数据
     */
    fun clearAppointmentMarker() {
        isAppointmentSucceed = false
        isRefreshEnable = true
        curSelectMarker?.let {
            if (onMapCancelListener != null) {
                onMapCancelListener?.onMapClick(it)
            }
            it.hideInfoWindow()
            if (markerList.containsValue(it)) {
                it.setIcon(AMapUtil.getBitmapDescriptor(R.mipmap.bike_marker_icon))
            } else {
                it.destroy()
            }
            null
        }


    }

    /**
     * 添加Marker
     * @param markerItemList
     */
    fun addMarker(markerItemList: ArrayList<MarkerBean>?) {

        Thread(Runnable {
            clearMarker()

            markerItemList?.let {
                for (markerBean in it) {
                    if (markerBean == null) {
                        continue
                    }

                    var icon = 0
                    if (markerBean.iconType == 1) {
                        icon = R.mipmap.bike_marker_icon
                    } else if (markerBean.iconType == 2) {
                        icon = R.mipmap.bike_marker_icon
                    }

                    val marker = mapView.addMarker(LatLng(markerBean.latitude, markerBean.longitude), icon, true)
                    if (marker != null) {
                        marker.`object` = markerBean
                        markerList[markerBean.bikeId] = marker
                    }

                    curSelectMarker?.setToTop()
                }
            }
        }).start()
    }

    /**
     * 是否存在marker
     */
    fun isHasMarkerById(bikeId: Int): Marker? {
        for (entry in markerList) {
            if (entry.key == bikeId) {
                return entry.value
            }
        }
        return null
    }

    override fun onMarkerClick(marker: Marker?) {
        if (isAppointmentSucceed) {
            return
        }
        setMarkerClick(marker)
    }

    fun setMarkerClick(marker: Marker?) {
        marker?.let {
            var markerBean = it.`object`
            if (markerBean != null) {
                markerBean = markerBean as MarkerBean

                if (markerBean != null) {
                    if (curSelectMarker != null) {
                        // 修改图标
                        curSelectMarker?.setIcon(AMapUtil.getBitmapDescriptor(R.mipmap.bike_marker_icon))
                    }

                    curSelectMarker = it

                    if (onMarkerClickListener != null) {
                        onMarkerClickListener?.onMarkerClick(it)
                    }
                }
            }
        }

    }

    override fun onMapClick(latLng: LatLng?) {

        if (isAppointmentSucceed) {
            return
        }

        curSelectMarker?.let {
            if (onMapCancelListener != null) {
                onMapCancelListener?.onMapClick(it)
            }

            clearRouteOverlay()
            it.setIcon(AMapUtil.getBitmapDescriptor(R.mipmap.bike_marker_icon))
            it.hideInfoWindow()
            null
        }
    }

    /**
     * 清除路线
     */
    fun clearRouteOverlay() {
        if (null == mRideRouteOverlay) {
            return
        }
        if (null != mRideRouteOverlay) {
            mRideRouteOverlay!!.removeFromMap()
            mRideRouteOverlay = null
        }

        mapView.map.animateCamera(CameraUpdateFactory.changeLatLng(mCurLatlng), 1, object : AMap.CancelableCallback {
            override fun onFinish() {
                if (mRideRouteOverlay == null) {
                    isRefreshEnable = true
                }
            }

            override fun onCancel() {
                if (mRideRouteOverlay == null) {
                    mapView.map.moveCamera(CameraUpdateFactory.changeLatLng(mCurLatlng))
                    isRefreshEnable = true
                }
            }
        })
    }


    private var walkTime: Long = 0
    private var walkDistance: Double = 0.0

    override fun infoWindowView(marker: Marker): View? {
        var infoWindow: View? = null
        if (infoWindow == null) {
            infoWindow = LayoutInflater.from(mContext).inflate(
                    R.layout.main_wininfo, null)
        }

        val mWalkTimeTextView = infoWindow?.findViewById<TextView>(R.id.walkTimeTextView)
        val mWalkDistanceTextView = infoWindow?.findViewById<TextView>(R.id.walkDistanceTextView)
        val iconImageView = infoWindow?.findViewById<ImageView>(R.id.iconImageView)


        iconImageView?.setImageResource(R.mipmap.bicycle_infowindow_icon)
        mWalkTimeTextView?.text = (if (walkTime == 0L) 1 else walkTime).toString() + "分钟"
        if (walkDistance >= 1000) {
            mWalkDistanceTextView?.text = "${ToolBox.getTwoDecimal(walkDistance / 1000)}千米"
        } else {
            mWalkDistanceTextView?.text = "${ToolBox.getTwoDecimal(walkDistance)}米"
        }


        return infoWindow
    }

    override fun onInfoWindowClick(marker: Marker?) {

    }

    override fun onWalkSearchRouteResult(isSucess: Boolean, distance: Int, walkPath: WalkPath?, startPoint: LatLonPoint?,
                                         targetPoint: LatLonPoint?) {

    }

    override fun onRideSearchRouteResult(isSucess: Boolean, distance: Int, ridePath: RidePath?, startPoint: LatLonPoint?,
                                         targetPoint: LatLonPoint?) {

        clearRouteOverlay()
        mRideRouteOverlay = RideRouteOverlay(mContext, mapView.map, ridePath, startPoint, targetPoint, BitmapDescriptorFactory.fromResource(R.mipmap.zuobiao_icon))
        mRideRouteOverlay?.let {
            mRideRouteOverlay?.removeFromMap()
            mRideRouteOverlay?.addToMap()
            mRideRouteOverlay?.zoomToSpan(mViewPaddingTop, mViewPaddingBottom, null)

            walkTime = (ridePath?.duration as Long) / 60
            walkDistance = ridePath?.distance.toDouble()

            if (curSelectMarker != null) {
                curSelectMarker?.showInfoWindow()
            }

            mSearchRouteResultListener?.searchRouteResult(true, distance, curSelectMarker)
        }
    }

    override fun onMapStable() {
        if (System.currentTimeMillis() - lastTime < 500) {
            return
        }
        lastTime = System.currentTimeMillis()
        mHandler?.postDelayed(Runnable {

            if (!isRefreshEnable || isAppointmentSucceed) {
                return@Runnable
            }

            if (!mapView.isStable) {
                return@Runnable
            }

            if (CommData.locationConfig == null) {
                return@Runnable
            }

            getRefreshDistance()

            val curLocationConfig = mapView.centerLocationConfig

            val latLng = curLocationConfig.latLng

            val lLocationConfig = mapView.centerLocationConfig

            val mLatLng = lLocationConfig.latLng

            mCurLatlng = mLatLng

            val distance = AMapUtils.calculateLineDistance(mLastLatlng, mCurLatlng)
            if (refreshDistance <= distance||mLastLatlng==null) {
                mLastLatlng = latLng
                if (mRefreshMapMoveListener != null) {
                    clearMarker()
                    mRefreshMapMoveListener!!.onRefreshData(lLocationConfig, true)
                }
            } else {
                if (mRefreshMapMoveListener != null) {
                    mRefreshMapMoveListener!!.onRefreshData(lLocationConfig, false)
                }
            }
        }, 100)
    }


    private fun getRefreshDistance() {
        val zoomLevel = mapView.map.cameraPosition.zoom.toInt()

        if (zoomLevel >= 15) {
            refreshDistance = ZOOM_LEVEL_REFRESH_DISTANCE_BIKE_17
        } else if (zoomLevel >= 12) {
            refreshDistance = ZOOM_LEVEL_REFRESH_DISTANCE_BIKE_16
        } else {
            refreshDistance = ZOOM_LEVEL_REFRESH_DISTANCE_BIKE_12
        }

    }


    //线路搜索结果回调
    private var mSearchRouteResultListener: SearchRouteResultListener? = null

    fun setSearchRouteResultListener(mSearchRouteResultListener: SearchRouteResultListener) {
        this.mSearchRouteResultListener = mSearchRouteResultListener
    }


    fun clearMarker() {
        markerList?.let {
            for (map in markerList.entries) {
                map.value.destroy()
            }
            markerList.clear()
        }
    }

    /**
     * 移动到大头针位置
     */
    fun moveToLocationLatLng(mViewPaddingTop: Int, mViewPaddingBottom: Int) {

        val bound = LatLngBounds.builder()
        bound.include(mCurLatlng)

        mapView.map?.animateCamera(CameraUpdateFactory.newLatLngBoundsRect(bound.build(),
                0, mViewPaddingTop, 0, mViewPaddingBottom), 300, object : AMap.CancelableCallback {
            override fun onFinish() {
                isRefreshEnable = false
                val locationConfig = mapView.centerLocationConfig
                if (onAnimatorCallback != null) {
                    onAnimatorCallback!!.onFinish(locationConfig)
                }
            }

            override fun onCancel() {
                isRefreshEnable = true
            }
        })
    }

    /**
     * 路线规划
     */
    fun searchRouteResult() {
        curSelectMarker?.let {
            val position = it.position ?: return

            it.setIcon(AMapUtil.getBitmapDescriptor(R.mipmap.bike_marker_select_icon))
            mapView.searchRouteResult(GDMapView.ROUTE_TYPE_ROUTE, LatLonPoint(mCurLatlng!!.latitude,
                    mCurLatlng!!.longitude), LatLonPoint(position.latitude, position.longitude), false)
        }

    }

    private var onMarkerClickListener: MapCallback.OnMarkerClickListener? = null

    fun setOnMarkerClickListener(onMarkerClickListener: MapCallback.OnMarkerClickListener) {
        this.onMarkerClickListener = onMarkerClickListener
    }

    private var onMapCancelListener: MapCallback.OnMapCancelListener? = null

    fun setOnMapCancelListener(onMapCancelListener: MapCallback.OnMapCancelListener) {
        this.onMapCancelListener = onMapCancelListener
    }

    fun setRefreshMapMoveListener(mRefreshMapMoveListener: RefreshMapMoveListener) {
        this.mRefreshMapMoveListener = mRefreshMapMoveListener
    }

    /**
     * 移动视图刷新数据接口
     */
    interface RefreshMapMoveListener {
        fun onRefreshData(cameraPosition: LocationConfig, isRefresh: Boolean)
    }

    fun setOnAnimatorCallback(onAnimatorListener: MapCallback.OnAnimatorCallback) {
        this.onAnimatorCallback = onAnimatorListener
    }
}