package com.baojia.mebike.feature.exclusive.shopping.selectBackAddress

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import android.view.View
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.amap.api.maps.model.Marker
import com.amap.api.services.core.PoiItem
import com.baojia.mebike.R
import com.baojia.mebike.base.BaseActivity
import com.baojia.mebike.data.CommData
import com.baojia.mebike.data.service_area.PersonServiceAreaObservable
import com.baojia.mebike.data.response.area.AreaResponse
import com.baojia.mebike.map.LocationConfig
import com.baojia.mebike.map.MapCallback
import com.baojia.mebike.util.DensityUtil
import com.baojia.mebike.util.recyclerview.RecycleViewDivider
import com.google.android.material.bottomsheet.BottomSheetBehavior
import kotlinx.android.synthetic.main.activity_select_back_address.*
import java.util.*

class SelectBackAddressActivity : BaseActivity(), SelectBackAddressContract.View, MapCallback.OnMarkerClickListener,
        MapCallback.OnMapCancelListener, View.OnClickListener, SelectBackAddressMapViewImp.RefreshListener, Observer {

    companion object {
        @JvmStatic
        fun startForResult(activity: Activity, requestCode: Int) {
            val intent = Intent()
            intent.setClass(activity, SelectBackAddressActivity::class.java)
            activity.startActivityForResult(intent, requestCode)
        }
    }

    private val resultCodeOk = 12

    private var mPresenter: SelectBackAddressContract.Presenter? = null
    private var mBottomSheetBehavior: BottomSheetBehavior<View>? = null
    private var mapViewImp: SelectBackAddressMapViewImp? = null
    private var selectBackAddressAdapter: SelectBackAddressAdapter? = null

    private var addressResult = ""
    private var mlastLatlng: LocationConfig? = CommData.locationConfig


    override fun layoutId(): Int = R.layout.activity_select_back_address

    private var poiList = arrayListOf<PoiItem>()

    override fun bindView(savedInstanceState: Bundle?) {

        mapViewAddress.onCreate(savedInstanceState)
        mapViewImp = SelectBackAddressMapViewImp(mapViewAddress, this)

        mBottomSheetBehavior = BottomSheetBehavior.from(bottomLayout)
        mBottomSheetBehavior?.state = BottomSheetBehavior.STATE_COLLAPSED
        mBottomSheetBehavior?.setBottomSheetCallback(mBottomSheetBehaviorCallback)

        mPresenter = SelectBackAddressPresenter(this, this)

        mapViewImp?.let {
            it.addLocation()
            it.moveToLocationLatLng(0, 0)
            it.refreshListener = this
        }

        setViewClickDuration(backButton, 1)
        setViewClickDuration(backBottomButton, 1)

        setRecyclerView()

        mPresenter?.searchPoi()
        mPresenter?.setPersonOperationArea()
    }


    private fun setRecyclerView() {
        poiInfoRecyclerView.layoutManager = LinearLayoutManager(this)
        selectBackAddressAdapter = SelectBackAddressAdapter(this, poiList, R.layout.item_power_station)
        poiInfoRecyclerView.adapter = selectBackAddressAdapter
        poiInfoRecyclerView.addItemDecoration(RecycleViewDivider(this, RecyclerView.VERTICAL, DensityUtil.dip2px(this, 1f), R.color.line_color))

        selectBackAddressAdapter?.let {
            it.setOnItemClickListner { _, position ->
                addressResult = "${poiList[position].provinceName ?: ""}${poiList[position].cityName
                        ?: ""}${poiList[position].adName ?: ""}${poiList[position].snippet ?: ""}"
                val intent = Intent()
                intent.putExtra("address", addressResult)
                intent.putExtra("takeLatitude", poiList[position].latLonPoint.latitude)
                intent.putExtra("takeLongitude", poiList[position].latLonPoint.longitude)
                setResult(resultCodeOk, intent)
                this@SelectBackAddressActivity.finish()
            }
        }

    }

    override fun setViewClick(view: View?) {
        super.setViewClick(view)
        when (view) {
            backButton -> {
                setResult(11)
                this@SelectBackAddressActivity.finish()
            }
            backBottomButton -> {
                mBottomSheetBehavior?.state = BottomSheetBehavior.STATE_COLLAPSED
            }
        }
    }

    override fun onBackPressed() {
        setResult(11)
        super.onBackPressed()
    }


    override fun onResume() {
        super.onResume()
        mapViewImp?.onResume()
        PersonServiceAreaObservable.getInstance().addObserver(this)
    }

    override fun onPause() {
        super.onPause()
        mapViewImp?.onPause()
    }

    override fun onDestroy() {
        super.onDestroy()
        mapViewImp?.onDestroy()
        PersonServiceAreaObservable.getInstance().deleteObserver(this)
    }

    private val mBottomSheetBehaviorCallback = object : BottomSheetBehavior.BottomSheetCallback() {

        override fun onStateChanged(bottomSheet: View, newState: Int) {
            if (poiInfoBehaviorLayout.visibility == View.VISIBLE) {
                topLayout.visibility = View.VISIBLE
            } else {
                topLayout.visibility = View.INVISIBLE
            }
        }

        override fun onSlide(bottomSheet: View, slideOffset: Float) {
            if (poiInfoBehaviorLayout.visibility == View.VISIBLE) {
                topLayout.visibility = View.VISIBLE
            } else {
                topLayout.visibility = View.INVISIBLE
            }
        }
    }


    override fun setPoiData(markerBeanList: ArrayList<PoiItem>) {
        poiList.clear()
        poiList.addAll(markerBeanList)
        selectBackAddressAdapter?.notifyDataSetChanged()
        val height = CommData.getScreen()[1] * 242 / 667
        mBottomSheetBehavior?.peekHeight = height
        mBottomSheetBehavior?.state = BottomSheetBehavior.STATE_COLLAPSED

    }

    override fun setPresenter(presenter: SelectBackAddressContract.Presenter?) {
    }


    override fun onMarkerClick(marker: Marker?) {
    }

    override fun onMapClick(marker: Marker?) {

    }

    override fun onClick(v: View?) {
    }

    override fun searchLatLng(): LocationConfig? {
        return mlastLatlng
    }


    override fun onRefreshData(cameraPosition: LocationConfig) {
        mlastLatlng = cameraPosition
        mPresenter?.searchPoi()
    }

    override fun update(observable: Observable?, arg: Any?) {
        if (observable === PersonServiceAreaObservable.getInstance()) {
            // 个人运营区域
            mPresenter?.setPersonOperationArea()
        }
    }

    override fun drawPersonOperationArea(operationAreaList: MutableList<AreaResponse.DataBean.AreaVosBean>?) {
        mapViewImp?.drawServiceArea(operationAreaList, -1)
        mapViewImp?.drawServiceLine(operationAreaList, -1)
    }
}