package com.baojia.mebike.feature.exclusive.shopping.selectBackAddress

import android.app.Activity
import android.os.Handler
import android.view.LayoutInflater
import android.view.View
import android.widget.ImageView
import android.widget.TextView
import com.amap.api.mapcore.util.it
import com.amap.api.maps.AMapUtils
import com.amap.api.maps.CameraUpdateFactory
import com.amap.api.maps.model.LatLng
import com.amap.api.maps.model.LatLngBounds
import com.amap.api.maps.model.Marker
import com.amap.api.services.core.LatLonPoint
import com.amap.api.services.route.RidePath
import com.amap.api.services.route.WalkPath
import com.baojia.mebike.R
import com.baojia.mebike.data.CommData
import com.baojia.mebike.data.response.exclusive.PowerStationResponse
import com.baojia.mebike.map.*
import com.baojia.mebike.map.miinterface.RideRouteOverlay
import com.baojia.mebike.map.miinterface.SearchRouteResultListener

/**
 * +----------------------------------------------------------------------
 * | @time 2018/12/20:5:55 PM
 * | @author house
 * | @class_describe
 * +----------------------------------------------------------------------
 **/
class SelectBackAddressMapViewImp constructor(mapView: GDMapView, mContext: Activity) : ReturnAreaMapImp(mapView, mContext)
        , MapCallback.OnMapClickListener
        , MapCallback.OnMapStableCallback {



    init {
        mapView.setMapStableCallback(this)
        mapView.setOnMapClickListener(this)
    }


    private var lastTime: Long = 0
    private var mHandler: Handler? = Handler()
    // 刷新距离
    private var refreshDistance = 500
    // 最后大头针定位点
    private var mLastLatlng: LatLng? = CommData.locationConfig.latLng

    fun addLocation() {
        mapView.addLocationMarker(CommData.locationConfig.latLng)
    }

    override fun onMapClick(latLng: LatLng?) {

    }

    /**
     * 移动到大头针位置
     */
    fun moveToLocationLatLng(mViewPaddingTop: Int, mViewPaddingBottom: Int) {

        val bound = LatLngBounds.builder()
        bound.include(CommData.locationConfig.latLng)

        mapView.map?.animateCamera(CameraUpdateFactory.newLatLngBoundsRect(bound.build(),
                0, mViewPaddingTop, 0, mViewPaddingBottom))
    }

    override fun onMapStable() {
        if (System.currentTimeMillis() - lastTime < 500) {
            return
        }
        lastTime = System.currentTimeMillis()
        mHandler?.postDelayed(Runnable {
            if (!mapView.isStable) {
                return@Runnable
            }

            if (CommData.locationConfig == null) {
                return@Runnable
            }


            val curLocationConfig = mapView.centerLocationConfig

            val latLng = curLocationConfig.latLng

            val distance = AMapUtils.calculateLineDistance(mLastLatlng, latLng)
            if (refreshDistance <= distance) {
                mLastLatlng = latLng
                refreshListener?.onRefreshData(curLocationConfig)
            }
        }, 100)

    }

    /**
     * 移动视图刷新数据接口
     */
    interface RefreshListener {
        fun onRefreshData(cameraPosition: LocationConfig)
    }
    var refreshListener :RefreshListener? = null
        set(value) {
            field = value
        }


    override fun onDestroy() {
        mHandler?.removeCallbacksAndMessages(null)
        mHandler = null

        mapView.onDestroy()
    }


}