package com.baojia.mebike.feature.join.details

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import android.view.View
import androidx.core.content.ContextCompat
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.baojia.mebike.R
import com.baojia.mebike.base.BaseActivity
import com.baojia.mebike.callback.IDialogCallback
import com.baojia.mebike.data.response.join.JoinOrderDetailsResponse
import com.baojia.mebike.util.DensityUtil
import com.baojia.mebike.util.recyclerview.RecycleViewDivider
import kotlinx.android.synthetic.main.activity_join_details.*

/**
 * +----------------------------------------------------------------------
 * | @time 2018/12/14:4:24 PM
 * | @author house
 * | @class_describe 订购详情
 * +----------------------------------------------------------------------
 **/
class JoinDetailsActivity : BaseActivity(), JoinDetailsContract.View, View.OnClickListener {



    private var joinDetailsAdapter: JoinDetailsAdapter? = null
    private val mData = arrayListOf<JoinOrderDetailsResponse.DataBean.DescribeListBean>()
    private var mPresenter: JoinDetailsPresenter? = null
    private var orderNo: String = "1"
    private var isChange = false

    override fun layoutId(): Int {
        return R.layout.activity_join_details
    }

    override fun bindView(savedInstanceState: Bundle?) {
        setTitleBackground(R.color.white_color)

        orderNo = intent.getStringExtra("orderNo")

        initRecyclerView()

        mPresenter = JoinDetailsPresenter(this, this)


    }

    private fun initRecyclerView() {
        detailsRecyclerView.layoutManager = LinearLayoutManager(this)
        joinDetailsAdapter = JoinDetailsAdapter(supportFragmentManager, this, mData, R.layout.item_join_details)
        detailsRecyclerView.adapter = joinDetailsAdapter
        detailsRecyclerView.addItemDecoration(RecycleViewDivider(this, RecyclerView.VERTICAL, DensityUtil.dip2px(this, 10f), R.color.white_color))
    }

    override fun setLeftButtonOnClickListener() {
        if (isChange) {
            setResult(11)
        } else {
            setResult(12)
        }
        finish()
    }

    override fun onResume() {
        super.onResume()
        mPresenter?.getDetails()
    }

    /**
     * 显示购买意向
     */
    override fun setTitleInfo(title: String?) {
        amountTextView.text = title
        unitTextView.visibility = View.VISIBLE
    }

    override fun setStatusInfo(statusInfo: String?) {
        introduceTextView.text = statusInfo
    }

    override fun setStatusInfoTextColor(colorRes: Int) {
        introduceTextView.setTextColor(ContextCompat.getColor(this, colorRes))
    }

    override fun setTitleByAbandon() {
        amountTextView.text = "已放弃加盟"
        unitTextView.visibility = View.GONE
        introduceTextView.text = ""
    }

    /**
     * 进度显示
     */
    override fun showProgress(flag: Int) {
        var visible = View.GONE
        if (flag > 0) {
            visible = View.VISIBLE
        }
        leftRoundImageView.visibility = visible
        rightRoundImageView.visibility = visible
        leftLineImageVIew.visibility = visible
        rightLineImageView.visibility = visible
        leftIntroduceTextView.visibility = visible
        leftDateTextView.visibility = visible
        rightIntroduceTextView.visibility = visible
        rightDateTextView.visibility = visible
        centerImageView.visibility = visible
    }

    /**
     * 出售车辆按钮布局显示
     */
    override fun showBottom() {
        bottomImageView.visibility = View.VISIBLE
        bottomLineImageView.visibility = View.VISIBLE
        sellButton.visibility = View.VISIBLE
        sellButton.setOnClickListener(this)
    }

    override fun hintBottom() {
        bottomImageView.visibility = View.GONE
        bottomLineImageView.visibility = View.GONE
        sellButton.visibility = View.GONE
    }

    override fun isVisibleTitleBar(): Boolean {
        return true;
    }

    override fun setTitleResId(): Int {
        return R.string.join_buy_details_title
    }

    override fun setRecyclerViewData(mData: ArrayList<JoinOrderDetailsResponse.DataBean.DescribeListBean>) {
        this.mData.clear()
        this.mData.addAll(mData)
        joinDetailsAdapter?.notifyDataSetChanged()
    }

    override fun setPresenter(presenter: JoinDetailsContract.Presenter?) {
        setIPresenter(presenter)
    }

    override fun orderNo(): String {
        return orderNo
    }

    override fun setProgressInfo(processFlag: Int, processRightDate: String?, processRightStr: String?, processLeftDate: String?, processLeftStr: String?) {

        showProgress(processFlag)
        if (processFlag > 0) {
            leftIntroduceTextView.text = processLeftStr
            leftDateTextView.text = processLeftDate
            rightIntroduceTextView.text = processRightStr
            rightDateTextView.text = processRightDate
        }
    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.sellButton -> {
                mPresenter?.getSellDialogBundle()?.let {
                    val joinSellDialog = JoinSellDialog()
                    joinSellDialog.arguments = mPresenter?.getSellDialogBundle()
                    joinSellDialog.show(supportFragmentManager, "sellDialog")
                    joinSellDialog.setDialogCallback(object : IDialogCallback() {
                        override fun onConfirm() {
                            super.onConfirm()
                            // 请求出售车辆接口
                            mPresenter?.sellBike()
                            isChange = true
                        }
                    })
                }
            }

        }
    }

    override fun onBackPressed() {
        if (isChange){
            setResult(11)
        }else{
            setResult(12)
        }
        super.onBackPressed()
    }

    companion object {
        fun start(activity: Activity, orderNo: String) {
            val intent = Intent()
            intent.setClass(activity, JoinDetailsActivity::class.java)
            intent.putExtra("orderNo", orderNo)
            activity.startActivity(intent)
        }
    }
}
