package com.baojia.mebike.feature.join.details

import android.app.Activity
import android.os.Bundle
import android.text.TextUtils
import com.baojia.mebike.R
import com.baojia.mebike.base.BasePresenter
import com.baojia.mebike.callback.HttpCallback
import com.baojia.mebike.data.dataenum.JoinOrderStatus
import com.baojia.mebike.data.response.BaseResponse
import com.baojia.mebike.data.response.join.JoinOrderDetailsResponse

/**
 * +----------------------------------------------------------------------
 * | @time 2018/12/14:6:03 PM
 * | @author house
 * | @class_describe
 * +----------------------------------------------------------------------
 **/
class JoinDetailsPresenter constructor(val mContext: Activity, val mView: JoinDetailsContract.View) :
        BasePresenter(mContext), JoinDetailsContract.Presenter {


    private var bundle: Bundle? = null


    private var joinDetailsModel: JoinDetailsModel?

    init {
        mView.setPresenter(this)
        joinDetailsModel = JoinDetailsModel(mContext)
    }

    override fun getDetails() {
        joinDetailsModel?.getOrderDetails(mView.orderNo(), object : HttpCallback<JoinOrderDetailsResponse.DataBean>() {
            override fun onSucceed(data: JoinOrderDetailsResponse.DataBean) {
                super.onSucceed(data)

                data.describeList?.let {
                    val mData: ArrayList<JoinOrderDetailsResponse.DataBean.DescribeListBean> = arrayListOf()
                    for ((position, list) in data.describeList.withIndex()) {
                        for (bean in list) {
                            bean.lineFlag = position
                            mData.add(bean)
                        }
                    }
                    mView.setRecyclerViewData(mData)
                }

                mView.setProgressInfo(data.processFlag, data.processRightDate, data.processRightStr, data.processLeftDate, data.processLeftStr)

                mView.hintBottom()

                if (data.orderStatus == JoinOrderStatus.ORDER_ALREADY_ABANDON.status) {
                    // 放弃加盟
                    mView.setTitleByAbandon()
                } else {
                    // 显示单位金额
                    mView.setTitleInfo(data.titleText)
                    mView.setStatusInfo(data.statusText)
                    if (data.orderStatus == JoinOrderStatus.ORDER_NO_PAY_NO_AUDIT.status ||
                            data.orderStatus == JoinOrderStatus.ORDER_ON_OFFER.status ||
                            data.orderStatus == JoinOrderStatus.ORDER_ALREADY_PAY_NO_AUDIT_ALREADY_ABANDON.status) {
                        // 显示红色
                        mView.setStatusInfoTextColor(R.color.focus_text_color)
                    } else if (data.orderStatus == JoinOrderStatus.ORDER_ALREADY_PAY_NO_AUDIT.status) {
                        // 显示橙色
                        mView.setStatusInfoTextColor(R.color.second_other_color)
                    } else if (data.orderStatus == JoinOrderStatus.ORDER_OPERATING.status ||
                            data.orderStatus == JoinOrderStatus.ORDER_ALREADY_OFFER.status) {
                        // 已投放运营
                        mView.setStatusInfoTextColor(R.color.text_third_color)
                        bundle = Bundle()
                        bundle?.putString("title", data.popTitle)
                        bundle?.putString("content", data.popContent)
                        if (!TextUtils.isEmpty(data.colorValue)) {
                            bundle?.putString("colorValue", data.colorValue)
                        }

                        mView.showBottom()
                    } else {
                        mView.setStatusInfoTextColor(R.color.text_second_color)
                    }
                }
            }
        })
    }

    override fun getSellDialogBundle(): Bundle? {
        return bundle
    }


    override fun sellBike() {
        joinDetailsModel?.sellBike(mView.orderNo(), object : HttpCallback<BaseResponse>() {

            override fun onSucceed(data: BaseResponse?) {
                super.onSucceed(data)
                getDetails()
            }
        })
    }
}