package com.baojia.mebike.feature.join.myjoin

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import android.text.TextUtils
import android.view.View
import androidx.core.content.ContextCompat
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.baojia.mebike.R
import com.baojia.mebike.base.BaseActivity
import com.baojia.mebike.data.response.join.MyJoinResponse
import com.baojia.mebike.feature.join.details.JoinDetailsActivity
import com.baojia.mebike.util.Toast
import com.baojia.mebike.util.ToolBox
import com.scwang.smartrefresh.header.MaterialHeader
import com.scwang.smartrefresh.layout.api.RefreshLayout
import com.scwang.smartrefresh.layout.listener.OnLoadmoreListener
import com.scwang.smartrefresh.layout.listener.OnRefreshListener
import kotlinx.android.synthetic.main.layout_nodata.*
import kotlinx.android.synthetic.main.layout_page_error.*
import kotlinx.android.synthetic.main.layout_page_no_net.*
import kotlinx.android.synthetic.main.layout_recyclerview_only.*

class MyJoinActivity : BaseActivity(), MyJoinContract.View, OnRefreshListener, OnLoadmoreListener {

    private val presenter: MyJoinPresenter = MyJoinPresenter(this, this)

    private val mDatas = ArrayList<MyJoinResponse.DataBean.OrderBean>()

    private val mAdapter = MyJoinAdapter(this, mDatas, R.layout.item_my_join_order)
    override fun layoutId(): Int = R.layout.layout_recyclerview_only
    override fun isVisibleTitleBar(): Boolean = true

    override fun setTitle(): String = "我的订购"

    override fun bindView(saedInstanceState: Bundle?) {
        recyclerview.setBackgroundColor(ToolBox.getColor(R.color.background_color))

        //刷新效果添加    也可以全局设置在application里边
        refreshLayout.refreshHeader = MaterialHeader(this).setShowBezierWave(false).setColorSchemeColors(ContextCompat.getColor(this, R.color.main_color)) //设置刷新为官方推介
        refreshLayout.setEnableHeaderTranslationContent(false)//刷新时和官方一致   内容不随刷新动
        refreshLayout.setPrimaryColorsId(R.color.main_color, R.color.main_color, R.color.main_color) //圈圈颜色

        val manager = LinearLayoutManager(this, RecyclerView.VERTICAL, false)
        recyclerview.layoutManager = manager
        recyclerview.setHasFixedSize(true)

        recyclerview.adapter = mAdapter

        refreshLayout.setOnRefreshListener(this)
        refreshLayout.setOnLoadmoreListener(this)

        setViewClickDuration(btPageErrorRefresh, 1)
        setViewClickDuration(btTrayAgain, 1)

        mAdapter.setOnItemClickListner { _, position ->
            run {
                //                JoinDetailsActivity.start(this, mDatas[position].orderNo)
                val intent = Intent()
                intent.setClass(this@MyJoinActivity, JoinDetailsActivity::class.java)
                intent.putExtra("orderNo", mDatas[position].orderNo)
                startActivityForResult(intent, 66)
            }
        }

        refreshLayout.autoRefresh()
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        if (requestCode == 66) {
            if (resultCode == 11) {
                refreshLayout?.autoRefresh()
            }
        }
    }


    override fun setViewClick(view: View?) {
        super.setViewClick(view)
        when (view) {
            btPageErrorRefresh -> refreshLayout.autoRefresh()
            btTrayAgain -> refreshLayout.autoRefresh()
        }
    }

    override fun refreshDataSucceed() {
        //结束刷新
        refreshLayout.finishRefresh()
        refreshLayout.isLoadmoreFinished = false
    }

    override fun refreshDataFailed(result: String) {
        refreshLayout.finishRefresh().isLoadmoreFinished = true
        if (!TextUtils.isEmpty(result)) {
            Toast.show(this, result)
        }
    }

    override fun loadMoreDataSucceed() {
        refreshLayout.finishLoadmore(true)

    }

    override fun loadMoreDataFailed(result: String) {
        refreshLayout.finishLoadmore().isLoadmoreFinished = false
        if (!TextUtils.isEmpty(result)) {
            Toast.show(this, result)
        }
    }

    override fun showNoDataPage() {
        if (mAdapter.itemCount <= 0) {
            llNodata.visibility = View.VISIBLE
        }
        refreshLayout.isLoadmoreFinished = true
    }

    override fun showNoNetPage() {
        if (mAdapter.itemCount <= 0) {
            llNonet.visibility = View.VISIBLE
        }
        refreshLayout.isLoadmoreFinished = true
    }

    override fun showErrorPage() {
        if (mAdapter.itemCount <= 0) {
            llError.visibility = View.VISIBLE
        }
        refreshLayout.isLoadmoreFinished = true
    }

    override fun hideAllPage() {
        llNonet.visibility = View.GONE
        llError.visibility = View.GONE
        llNodata.visibility = View.GONE
    }

    override fun setMyJoinDatas(mDatas: List<MyJoinResponse.DataBean.OrderBean>, isRefresh: Boolean) {
        if (isRefresh) {
            this.mDatas.clear()
        }
        this.mDatas.addAll(mDatas)
        mAdapter.notifyDataSetChanged()
    }

    override fun onLoadmore(refreshlayout: RefreshLayout) {
        refreshLayout.finishRefresh(5000)//五秒后接口还没通强制关闭刷新效果
        presenter.getMyJoinlList(false)
    }

    override fun onRefresh(refreshlayout: RefreshLayout) {
        refreshLayout.finishRefresh(5000)//五秒后接口还没通强制关闭刷新效果
        presenter.getMyJoinlList(true)
    }

    override fun setPresenter(presenter: MyJoinContract.Presenter) {}

    companion object {
        @JvmStatic
        fun start(activity: Activity) {
            val intent = Intent()
            intent.setClass(activity, MyJoinActivity::class.java)
            activity.startActivity(intent)
        }
    }

}