package com.baojia.mebike.feature.join.record

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import android.text.TextUtils
import android.view.View
import androidx.core.content.ContextCompat
import androidx.recyclerview.widget.LinearLayoutManager
import com.baojia.mebike.R
import com.baojia.mebike.base.BaseActivity
import com.baojia.mebike.data.response.join.JoinRecordResponse
import com.baojia.mebike.util.JumpActivity
import com.baojia.mebike.util.Toast
import com.scwang.smartrefresh.header.MaterialHeader
import com.scwang.smartrefresh.layout.api.RefreshLayout
import com.scwang.smartrefresh.layout.listener.OnLoadmoreListener
import com.scwang.smartrefresh.layout.listener.OnRefreshListener
import kotlinx.android.synthetic.main.layout_nodata.*
import kotlinx.android.synthetic.main.layout_page_error.*
import kotlinx.android.synthetic.main.layout_page_no_net.*
import kotlinx.android.synthetic.main.layout_recyclerview_only.*

/**
 * +----------------------------------------------------------------------
 * | @time 2018/12/17:3:40 PM
 * | @author house
 * | @class_describe 分成记录/提现记录
 * +----------------------------------------------------------------------
 **/
class JoinRecordListActivity : BaseActivity(), JoinRecordContract.View, OnRefreshListener, OnLoadmoreListener {


    companion object {
        fun start(activity: Activity, intentType: Int = 0) {
            val intent = Intent()
            intent.setClass(activity, JoinRecordListActivity::class.java)
            intent.putExtra("intentType", intentType)
            activity.startActivity(intent)
        }
    }

    // 跳转类型 0：分成记录 1：提现记录
    private var intentType: Int = 0;

    private var mData: ArrayList<JoinRecordResponse.DataBean> = arrayListOf()
    private var recordListAdapter: JoinRecordListAdapter? = null
    private var mPresenter: JoinRecordPresenter? = null

    override fun layoutId(): Int {
        return R.layout.layout_recyclerview_only
    }

    override fun bindView(savedInstanceState: Bundle?) {

        refreshLayout.setBackgroundColor(ContextCompat.getColor(this, R.color.background_color))
        recyclerview.setBackgroundColor(ContextCompat.getColor(this, R.color.transparent))
        setTitleBackground(R.color.title_background_color)

        intentType = intent.getIntExtra("intentType", 0)

        noDataImageView.setBackgroundResource(R.drawable.icon_none_detail)

        if (intentType == 0) {
            setTitle(R.string.income_record_title)
        } else if (intentType == 1) {
            setTitle(R.string.withdraw_record_title)
        }
        mPresenter = JoinRecordPresenter(this, this)

        initRecyclerView()
    }

    private fun initRecyclerView() {


        //刷新效果添加    也可以全局设置在application里边
        refreshLayout.refreshHeader = MaterialHeader(this).setShowBezierWave(false)
                .setColorSchemeColors(ContextCompat.getColor(this, R.color.main_color)) //设置刷新为官方推介
        refreshLayout.setEnableHeaderTranslationContent(false)//刷新时和官方一致   内容不随刷新动
        refreshLayout.setPrimaryColorsId(R.color.main_color, R.color.main_color, R.color.main_color) //圈圈颜色


        refreshLayout.setOnRefreshListener(this)
        refreshLayout.setOnLoadmoreListener(this)

        setViewClickDuration(btPageErrorRefresh, 1)
        setViewClickDuration(btTrayAgain, 1)


        recordListAdapter = JoinRecordListAdapter(this, mData, R.layout.item_earning_detail)

        recyclerview.layoutManager = LinearLayoutManager(this)
        recyclerview.adapter = recordListAdapter
//        recyclerview.addItemDecoration(RecycleViewDivider(this, RecyclerView.VERTICAL, DensityUtil.dip2px(this, 10f), R.color.transparent))
        recyclerview.setHasFixedSize(true)
        refreshLayout.autoRefresh()



        recordListAdapter?.let {
            it.setOnItemClickListner { _, position ->

                if (intentType == 1) {
                    // 提现可点击
                    JumpActivity.JumpWithdrawDepositResultActivity(this@JoinRecordListActivity,
                            mData[position].withdrawApplicationId.toString(), 6)
                }
            }
        }
    }

    override fun setViewClick(view: View?) {
        super.setViewClick(view)
        when (view?.id) {
            R.id.btPageErrorRefresh//加载错误
                , R.id.btTrayAgain//网络错误
            -> refreshLayout.autoRefresh()

        }
    }


    override fun getRecordType(): Int {
        return intentType
    }

    override fun setRecordData(mData: ArrayList<JoinRecordResponse.DataBean>?,isRefresh:Boolean) {
        if (isRefresh){
            this.mData.clear()
        }
        mData?.let { this.mData.addAll(it) }
        recordListAdapter?.notifyDataSetChanged()
    }

    override fun refreshDataSucceed() {
        //结束刷新
        refreshLayout.finishRefresh()
        refreshLayout.isLoadmoreFinished = false
    }

    override fun refreshDataFailed(result: String?) {
        refreshLayout.finishRefresh().isLoadmoreFinished = true
        if (!TextUtils.isEmpty(result)) {
            Toast.show(this, result)
        }
    }

    override fun loadMoreDataSucceed() {
        refreshLayout.finishLoadmore(true)
    }

    override fun loadMoreDataFailed(result: String?) {
        refreshLayout.finishLoadmore().isLoadmoreFinished = false
        if (!TextUtils.isEmpty(result)) {
            Toast.show(this, result)
        }
    }

    override fun showNoDataPage() {
        if (recordListAdapter?.itemCount as Int <= 0) {
            llNodata.visibility = View.VISIBLE
        }
        refreshLayout.isLoadmoreFinished = true
    }

    override fun showNoNetPage() {
        if (recordListAdapter?.itemCount as Int <= 0) {
            llNonet.visibility = View.VISIBLE
        }
        refreshLayout.isLoadmoreFinished = true
    }

    override fun showErrorPage() {
        if (recordListAdapter?.itemCount as Int <= 0) {
            llError.visibility = View.VISIBLE
        }
        refreshLayout.isLoadmoreFinished = true
    }

    override fun hideAllPage() {
        llNonet.visibility = View.GONE
        llError.visibility = View.GONE
        llNodata.visibility = View.GONE
    }

    override fun onLoadmore(refreshlayout: RefreshLayout?) {
        refreshlayout?.finishRefresh(5000)//五秒后接口还没通强制关闭刷新效果
        mPresenter?.getRecordData(false)
    }

    override fun onRefresh(refreshlayout: RefreshLayout?) {
        refreshlayout?.finishRefresh(5000)//五秒后接口还没通强制关闭刷新效果
        mPresenter?.getRecordData(true)
    }

    override fun setPresenter(presenter: JoinRecordContract.Presenter?) {
        this.setIPresenter(presenter)
    }

    override fun isVisibleTitleBar(): Boolean {
        return true
    }

}