package com.baojia.mebike.feature.join.record

import android.app.Activity
import com.baojia.mebike.R
import com.baojia.mebike.base.BaseModel
import com.baojia.mebike.callback.HttpCallback
import com.baojia.mebike.data.response.join.JoinRecordResponse
import com.baojia.mebike.http.HttpUtils
import io.reactivex.disposables.Disposable

/**
 * +----------------------------------------------------------------------
 * | @time 2018/12/17:7:30 PM
 * | @author house
 * | @class_describe
 * +----------------------------------------------------------------------
 **/

class JoinRecordModel constructor(context: Activity) : BaseModel(context) {
    // 提现明细列表
    private final val WITHDRAW_RECORD_URL = "/bike/get/withDrawList"
    // 收益明细列表
    private final val INCOME_RECORD_URL = "/bike/get/profitDetail"

    /**
     * 获取记录列表
     * @param recordType 1:提现明细 0：收益明细
     * @param pageNum 页码
     */
    fun getRecord(recordType: Int = 0, pageNum: Int, httpCallback: HttpCallback<ArrayList<JoinRecordResponse.DataBean>?>): Disposable {
        var params = mutableMapOf<String, Any?>()
        params["pageNum"] = pageNum
        params["pageSize"] = 20
        var url = INCOME_RECORD_URL
        when (recordType) {
            0 -> url = INCOME_RECORD_URL
            1 -> url = WITHDRAW_RECORD_URL
        }

        return HttpUtils.postRequest(activity, url, params, false, object : HttpCallback<JoinRecordResponse>() {
            override fun onSucceed(data: JoinRecordResponse?) {
                super.onSucceed(data)
                if (data == null) {
                    onFailed(-1, activity.getString(R.string.json_error))
                    return
                }
                httpCallback?.onSucceed(data.data)
            }

            override fun onFailed(code: Int, message: String?) {
                super.onFailed(code, message)
                httpCallback?.onFailed(code, message)
            }

            override fun onError(code: Int, message: String?) {
                super.onError(code, message)
                httpCallback?.onError(code, message)
            }
        }, JoinRecordResponse::class.java)
    }
}